

CREATE TABLE address (
 id INTEGER NOT NULL AUTO_INCREMENT,
 street1  VARCHAR(60) NOT NULL,
 street2  VARCHAR(60),
 city VARCHAR(60) NOT NULL,
 state  VARCHAR(2) NOT NULL,
 zip  VARCHAR(10) NOT NULL,
 country VARCHAR(50) NOT NULL,
 PRIMARY KEY (id));

CREATE TABLE groups (
 username VARCHAR(60) NOT NULL,
 group_name VARCHAR(60) NOT NULL,
 PRIMARY KEY (username, group_name));

CREATE TABLE medrec_user (
  username VARCHAR(45) NOT NULL,
  password VARCHAR(50) NOT NULL,
  status VARCHAR(15) NOT NULL,
  PRIMARY KEY (username));

CREATE TABLE patient  (
  id  INTEGER NOT NULL AUTO_INCREMENT,
  first_name  VARCHAR(60) NOT NULL,
  middle_name VARCHAR(60),
  last_name VARCHAR(60) NOT NULL,
  dob DATE NOT NULL,
  gender    VARCHAR(6) NOT NULL,
  ssn VARCHAR(9) NOT NULL,
  address_id INTEGER NOT NULL,
  phone VARCHAR(15),
  email VARCHAR(60) NOT NULL,
  PRIMARY KEY (id),
  FOREIGN KEY (address_id)
    REFERENCES address(id),
  FOREIGN KEY (email)
    REFERENCES medrec_user(username));

CREATE TABLE physician  (
 id INTEGER NOT NULL AUTO_INCREMENT,
 first_name VARCHAR(60) NOT NULL,
 middle_name  VARCHAR(60),
 last_name  VARCHAR(60) NOT NULL,
 phone  VARCHAR(15),
 email  VARCHAR(60),
 PRIMARY KEY (id));

CREATE TABLE vital_signs  (
 id INTEGER NOT NULL AUTO_INCREMENT,
 temperature VARCHAR(4),
 blood_pressure VARCHAR(10),
 pulse  VARCHAR(10),
 weight INTEGER,
 height INTEGER,
 PRIMARY KEY (id));

CREATE TABLE prescription (
 id INTEGER NOT NULL AUTO_INCREMENT,
 pat_id INTEGER NOT NULL,
 date_prescribed DATE NOT NULL,
 drug VARCHAR(80) NOT NULL,
 record_id INTEGER  NOT NULL,
 dosage VARCHAR(30) NOT NULL,
 frequency  VARCHAR(30),
 refills_remaining  INTEGER,
 instructions VARCHAR(255),
 PRIMARY KEY (id),
  FOREIGN KEY (pat_id)
    REFERENCES patient(id),
  FOREIGN KEY (record_id)
    REFERENCES record(id));

CREATE TABLE record (
 id INTEGER NOT NULL AUTO_INCREMENT,
 pat_id INTEGER NOT NULL,
 phys_id  INTEGER NOT NULL,
 record_date  DATE NOT NULL,
 vital_id INTEGER  NOT NULL,
 symptoms VARCHAR(255) NOT NULL,
 diagnosis  VARCHAR(255),
 notes  VARCHAR(255),
 PRIMARY KEY (id),
  FOREIGN KEY (pat_id)
    REFERENCES patient(id),
  FOREIGN KEY (phys_id)
    REFERENCES physician(id),
  FOREIGN KEY (vital_id)
    REFERENCES vital_signs(id));

COMMIT;
