-- MedRec - Data Definition Language

-- Drop Medrec tables
DROP TABLE address;
DROP TABLE groups;
DROP TABLE patient;
DROP TABLE physician;
DROP TABLE prescription;
DROP TABLE record;
DROP TABLE medrec_user;
DROP TABLE vital_signs;

-- Create Medrec tables
CREATE TABLE address	(
 id	INTEGER IDENTITY(110,1) CONSTRAINT address_pk PRIMARY KEY,
 street1	VARCHAR(60) NOT NULL,
 street2	VARCHAR(60),
 city	    VARCHAR(60) NOT NULL,
 state	  VARCHAR(2) NOT NULL,
 zip	    VARCHAR(10) NOT NULL,
 country  VARCHAR(50) NOT NULL,
 version INTEGER NOT NULL
);

CREATE TABLE medrec_user (
  username VARCHAR(60) NOT NULL CONSTRAINT username_pk PRIMARY KEY,
  password VARCHAR(50) NOT NULL,
  status   VARCHAR(15) NOT NULL,
  version INTEGER NOT NULL
);

CREATE TABLE groups	(
 username	  VARCHAR(60) NOT NULL,
 group_name	VARCHAR(60) NOT NULL,
 version INTEGER NOT NULL
);

CREATE TABLE patient	(
  id INTEGER IDENTITY(110,1) NOT NULL CONSTRAINT patient_pk PRIMARY KEY,
  first_name	VARCHAR(60) NOT NULL,
  middle_name	VARCHAR(60),
  last_name	  VARCHAR(60) NOT NULL,
  dob	        DATE NOT NULL,
  gender      VARCHAR(6) NOT NULL,
  ssn	        VARCHAR(9) NOT NULL,
  phone	      VARCHAR(15),
  email	      VARCHAR(60) NOT NULL,
  address_id  INTEGER NOT NULL,
  version INTEGER NOT NULL
  CONSTRAINT address_fk FOREIGN KEY (address_id) REFERENCES address (id)
  CONSTRAINT email_fk FOREIGN KEY (email) REFERENCES medrec_user (username)
);

CREATE TABLE physician	(
 id	INT IDENTITY(110,1) NOT NULL CONSTRAINT physician_pk PRIMARY KEY,
 first_name	  VARCHAR(60) NOT NULL,
 middle_name	VARCHAR(60),
 last_name	  VARCHAR(60) NOT NULL,
 phone	      VARCHAR(15),
 email	      VARCHAR(60),
 version INTEGER NOT NULL
);

CREATE TABLE vital_signs	(
 id	INTEGER IDENTITY(110,1) NOT NULL CONSTRAINT vital_signs_pk PRIMARY KEY,
 temperature    VARCHAR(4),
 blood_pressure	VARCHAR(10),
 pulse	        VARCHAR(10),
 weight         INTEGER,
 height         INTEGER,
 version INTEGER NOT NULL
);

CREATE TABLE record	(
 id	INTEGER IDENTITY(120,1) NOT NULL CONSTRAINT record_pk PRIMARY KEY,
 pat_id	      INTEGER NOT NULL,
 phys_id	    INTEGER NOT NULL,
 record_date	DATE NOT NULL,
 vital_id     INTEGER  NOT NULL,
 symptoms	    VARCHAR(255) NOT NULL,
 diagnosis	  VARCHAR(255),
 notes	      VARCHAR(255),
 version INTEGER NOT NULL
 CONSTRAINT patient_fk FOREIGN KEY (pat_id) REFERENCES patient (id)
 CONSTRAINT physician_fk FOREIGN KEY (phys_id) REFERENCES physician (id)
 CONSTRAINT vital_signs_fk FOREIGN KEY (vital_id) REFERENCES vital_signs (id)
);

CREATE TABLE prescription	(
 id INTEGER IDENTITY(110,1) NOT NULL CONSTRAINT prescription_pk PRIMARY KEY,
 pat_id	INTEGER NOT NULL,
 record_id INTEGER  NOT NULL,
 date_prescribed DATE NOT NULL,
 drug	VARCHAR(80) NOT NULL,
 dosage	VARCHAR(30) NOT NULL,
 frequency	VARCHAR(30),
 refills_remaining	INTEGER,
 instructions	VARCHAR(255),
 version INTEGER NOT NULL
 CONSTRAINT patient_fk FOREIGN KEY (pat_id) REFERENCES patient (id)
 CONSTRAINT record_fk FOREIGN KEY (record_id) REFERENCES record (id)
);

COMMIT;
