-- Create test data.
-- Caution: This script deletes all existing data.
-- Note: Sequence tables are created starting at 101.

ALTER TABLE patient DROP CONSTRAINT address_fk;
ALTER TABLE patient DROP CONSTRAINT email_fk;
ALTER TABLE record DROP CONSTRAINT patient_fk;
ALTER TABLE record DROP CONSTRAINT vital_signs_fk;
ALTER TABLE record DROP CONSTRAINT physician_fk;
ALTER TABLE prescription DROP CONSTRAINT record_fk;
ALTER TABLE prescription DROP CONSTRAINT patient_fk;

DELETE FROM patient;
DELETE FROM record;
DELETE FROM address;
DELETE FROM groups;
DELETE FROM medrec_user;
DELETE FROM physician;
DELETE FROM vital_signs;
DELETE FROM prescription;

-- Address
INSERT INTO address (id,version,street1,street2,city,state,zip,country) VALUES (101,0,'1224 Post St','Suite 100','San Francisco','CA','94115','United States');
INSERT INTO address (id,version,street1,street2,city,state,zip,country) VALUES (102,0,'235 Montgomery St','Suite 15','Ponte Verde','FL','32301','United States');
INSERT INTO address (id,version,street1,street2,city,state,zip,country) VALUES (103,0,'1234 Market','','San Diego','CA','92126','United States');

-- User
INSERT INTO medrec_user (username,password,version,status) VALUES ('volley@ball.com','{sha-1}JWMxUEYXBrFqQHTydHo9cnpAJ/Gq8QY=',0,'ACTIVE');
INSERT INTO medrec_user (username,password,version,status) VALUES ('page@fish.com','{sha-1}JWMxUEYXBrFqQHTydHo9cnpAJ/Gq8QY=',0,'ACTIVE');
INSERT INTO medrec_user (username,password,version,status) VALUES ('charlie@star.com','{sha-1}JWMxUEYXBrFqQHTydHo9cnpAJ/Gq8QY=',0,'NEW');
INSERT INTO medrec_user (username,password,version,status) VALUES ('fred@golf.com','{sha-1}JWMxUEYXBrFqQHTydHo9cnpAJ/Gq8QY=',0,'ACTIVE');
INSERT INTO medrec_user (username,password,version,status) VALUES ('larry@bball.com','{sha-1}JWMxUEYXBrFqQHTydHo9cnpAJ/Gq8QY=',0,'ACTIVE');

-- Groups
INSERT INTO groups (username,version,group_name) VALUES ('fred@golf.com',0,'MedRecPatients');
INSERT INTO groups (username,version,group_name) VALUES ('larry@bball.com',0,'MedRecPatients');
INSERT INTO groups (username,version,group_name) VALUES ('charlie@star.com',0,'MedRecPatients');
INSERT INTO groups (username,version,group_name) VALUES ('volley@ball.com',0,'MedRecPatients');
INSERT INTO groups (username,version,group_name) VALUES ('page@fish.com',0,'MedRecPatients');

-- Patient
INSERT INTO patient (id,version,first_name,middle_name,last_name,dob,gender,ssn,phone,email,address_id) VALUES (101,0,'Fred','I','Winner','1965-03-26','Male','123456789','4151234564','fred@golf.com',101);
INSERT INTO patient (id,version,first_name,middle_name,last_name,dob,gender,ssn,phone,email,address_id) VALUES (102 ,0,'Larry','J','Parrot','1959-02-13','Male','777777777','4151234564','larry@bball.com',101);
INSERT INTO patient (id,version,first_name,middle_name,last_name,dob,gender,ssn,phone,email,address_id) VALUES (103 ,0,'Charlie','E','Florida','1973-10-29','Male','444444444','4151234564','charlie@star.com',102);
INSERT INTO patient (id,version,first_name,middle_name,last_name,dob,gender,ssn,phone,email,address_id) VALUES (104 ,0,'Gabrielle','H','Spiker','1971-08-17','Female','333333333','4151234564','volley@ball.com',101);
INSERT INTO patient (id,version,first_name,middle_name,last_name,dob,gender,ssn,phone,email,address_id) VALUES (105 ,0,'Page','A','Trout','1972-02-18','Male','888888888','4151234564','page@fish.com',102);

-- Physician
INSERT INTO physician (id,version,first_name,middle_name,last_name,phone,email) VALUES (101,0,'Mary','J','Oblige','1234567812','mary@md.com');
INSERT INTO physician (id,version,first_name,middle_name,last_name,phone,email) VALUES (102 ,0,'Phil','B','Lance','1234567812','phil@syscon.com');
INSERT INTO physician (id,version,first_name,middle_name,last_name,phone,email) VALUES (103 ,0,'Kathy','E','Wilson','1234567812','kwilson@dr.com');

-- Vital Signs
INSERT INTO vital_signs (id,version,temperature,blood_pressure,pulse,weight,height) VALUES (101,0,'98','125/85','75',180,70);
INSERT INTO vital_signs (id,version,temperature,blood_pressure,pulse,weight,height) VALUES (102,0,'100','120/80','85',199,69);
INSERT INTO vital_signs (id,version,temperature,blood_pressure,pulse,weight,height) VALUES (103,0,'98','110/75','95',300,76);
INSERT INTO vital_signs (id,version,temperature,blood_pressure,pulse,weight,height) VALUES (104,0,'98','110/75','95',300,76);
INSERT INTO vital_signs (id,version,temperature,blood_pressure,pulse,weight,height) VALUES (105,0,'98','110/75','95',300,76);
INSERT INTO vital_signs (id,version,temperature,blood_pressure,pulse,weight,height) VALUES (106,0,'98','110/75','95',300,76);
INSERT INTO vital_signs (id,version,temperature,blood_pressure,pulse,weight,height) VALUES (107,0,'98','110/75','95',300,76);
INSERT INTO vital_signs (id,version,temperature,blood_pressure,pulse,weight,height) VALUES (108,0,'98','110/75','95',300,76);
INSERT INTO vital_signs (id,version,temperature,blood_pressure,pulse,weight,height) VALUES (109,0,'98','110/75','95',300,76);
INSERT INTO vital_signs (id,version,temperature,blood_pressure,pulse,weight,height) VALUES (110,0,'98','110/75','95',300,76);
INSERT INTO vital_signs (id,version,temperature,blood_pressure,pulse,weight,height) VALUES (111,0,'98','110/75','95',300,76);

-- Record
INSERT INTO record (id,version,pat_id,phys_id,record_date,vital_id,symptoms,diagnosis,notes) VALUES (101,0,101,102,'1999-06-18',101,'Complains about chest pain.','Mild stroke.  Aspirin advised.','Patient needs to stop smoking.');
INSERT INTO record (id,version,pat_id,phys_id,record_date,vital_id,symptoms,diagnosis,notes) VALUES (102,0,101,103,'1993-05-30',104,'Sneezing, coughing, stuffy head.','Common cold. Prescribed codiene cough syrup.','Call back if not better in 10 days.');
INSERT INTO record (id,version,pat_id,phys_id,record_date,vital_id,symptoms,diagnosis,notes) VALUES (103,0,101,102,'1989-07-05',105,'Twisted knee while playing soccer.','Severely sprained interior ligament.  Surgery required.','Cast will be necessary before and after.');
INSERT INTO record (id,version,pat_id,phys_id,record_date,vital_id,symptoms,diagnosis,notes) VALUES (104,0,103,103,'2000-02-18',102,'Exhaustion and extreme fatigue.','Mononucleosis.','Notes start here.');
INSERT INTO record (id,version,pat_id,phys_id,record_date,vital_id,symptoms,diagnosis,notes) VALUES (105,0,105,101,'1991-04-01',103,'Drowsy all day.','Allergic to coffee.  Drink tea.','No notes.');
INSERT INTO record (id,version,pat_id,phys_id,record_date,vital_id,symptoms,diagnosis,notes) VALUES (106,0,105,102,'1987-01-13',106,'Blurred vision.','Increased loss of vision due to recent car accident.','Admit patient to hospital.');
INSERT INTO record (id,version,pat_id,phys_id,record_date,vital_id,symptoms,diagnosis,notes) VALUES (107,0,105,101,'1990-09-09',107,'Sore throat.','Strep thoart culture taken.  Sleep needed.','Call if positive.');
INSERT INTO record (id,version,pat_id,phys_id,record_date,vital_id,symptoms,diagnosis,notes) VALUES (108,0,102,102,'2001-06-20',108,'Overjoyed with everything.','Patient is crazy.  Recommend politics.','');
INSERT INTO record (id,version,pat_id,phys_id,record_date,vital_id,symptoms,diagnosis,notes) VALUES (109,0,104,103,'2002-11-03',109,'Sprained ankle.','Lite cast needed.','At least 20 sprained ankles since 15.');
INSERT INTO record (id,version,pat_id,phys_id,record_date,vital_id,symptoms,diagnosis,notes) VALUES (110,0,103,103,'1997-12-21',110,'Forgetful, short-term memory not as sharpe.','General old age.','Patient will someday be 120 years old.');
INSERT INTO record (id,version,pat_id,phys_id,record_date,vital_id,symptoms,diagnosis,notes) VALUES (111,0,104,102,'2001-05-13',111,'Nothing is wrong.','This gal is fine.','Patient likes lobby magazines.');

-- Prescription
INSERT INTO prescription (id,version,pat_id,record_id,date_prescribed,drug,dosage,frequency,refills_remaining,instructions) VALUES (101,0,101,101,'1999-06-18','Advil','100 tbls','1/4hrs',0,'No instructions');
INSERT INTO prescription (id,version,pat_id,record_id,date_prescribed,drug,dosage,frequency,refills_remaining,instructions) VALUES (102,0,101,101,'1999-06-18','Drixoral','16 oz','1tspn/4hrs',0,'No instructions');
INSERT INTO prescription (id,version,pat_id,record_id,date_prescribed,drug,dosage,frequency,refills_remaining,instructions) VALUES (103,0,101,102,'1993-05-30','Codeine','10 oz','1/6hrs',1,'No instructions');
INSERT INTO prescription (id,version,pat_id,record_id,date_prescribed,drug,dosage,frequency,refills_remaining,instructions) VALUES (104,0,102,108,'2001-06-20','Valium','50 pills','1/day',3,'No instructions');

COMMIT;