package com.bea.medrec.domain;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * <p>Encapsulates patient's medical record summary.
 * Includes List<Object>of abbreviated records and
 * List<Object>of current and recent prescriptions.</p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public final class MedicalRecord implements Serializable {

  private Integer srcId;
  private String srcName;
  private Patient patient;
  private List records;

  public MedicalRecord() {
  }

  public MedicalRecord(Integer srcId, String srcName) {
    this.srcId = srcId;
    this.srcName = srcName;
  }

  public MedicalRecord(Integer srcId,
                       String srcName,
                       Patient patient,
                       List<Object> records) {
    this.srcId = srcId;
    this.srcName = srcName;
    this.patient = patient;
    this.records = records;
  }

  public MedicalRecord(Patient patient, List<Object> records) {
    this.patient = patient;
    this.records = records;
  }

  public Integer getSrcId() {
    return this.srcId;
  }

  public String getSrcName() {
    return this.srcName;
  }

  public Patient getPatient() {
    return this.patient;
  }

  public List<Object> getRecords() {
    return this.records == null ? new ArrayList<Object>() : this.records;
  }

  public User getUser() {
    return this.patient.getUser();
  }

  public void setSrcId(Integer srcId) {
    this.srcId = srcId;
  }

  public void setSrcName(String srcName) {
    this.srcName = srcName;
  }

  public void setPatient(Patient patient) {
    this.patient = patient;
  }

  public void setRecords(List records) {
    this.records = records;
  }

  public void setUser(User user) {
    this.patient.setUser(user);
  }

  public void addRecord(Record record) {
    if (records == null) records = new ArrayList<Object>();
    records.add(record);
  }

  public int numOfRecords() {
    return (records != null ? records.size() : 0);
  }

  public String toString() {
    StringBuffer str = new StringBuffer();
    str.append("MedicalRecord [");
    str.append("SrcId: ").append(srcId);
    str.append(" | SrcName: ").append(srcName);
    str.append(" | User: ").append(getUser().toString());
    str.append(" | Patient: ").append(patient.toString());
    str.append(" | Num of Records: ").append(getRecordCount());
    if (numOfRecords() > 0) {
      for (Object record1 : records) {
        Record record = (Record) record1;
        str.append(" | ").append(record.toString());
      }
    }
    str.append("]");
    return str.toString();
  }

  private String getRecordCount() {
    return (this.records == null ? "0" : String.valueOf(records.size()));
  }
}
