package com.bea.medrec.domain;

import java.io.Serializable;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;
import org.apache.commons.lang.builder.*;

import com.bea.medrec.utils.MedRecUtils;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Inheritance;
import javax.persistence.InheritanceType;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Version;

import kodo.persistence.jdbc.ElementJoinColumn;

import static javax.persistence.GenerationType.IDENTITY;
import static javax.persistence.CascadeType.PERSIST;
import static javax.persistence.CascadeType.MERGE;

/**
 * <p>
 * This class represents information about a patient.
 * </p>
 * 
 * @author Copyright (c)
 * @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 * 
 */

@NamedQueries( {
    @NamedQuery(name = "getPatientsByStatus", query = "SELECT p "
        + "FROM Patient p "
        + "WHERE p.user.status = ?1"),
    @NamedQuery(name = "getPatientsByUser", query = "SELECT p "
        + "FROM Patient p " + "WHERE p.user.username = ?1") })
        
/*
 * Declare that this class is a JPA entity.  The container will access
 * the fields of the class directly when it needs to read or write 
 * persistent values.
 */        
@Entity()

public class Patient implements Serializable
{
  @Id()
  @GeneratedValue(strategy=IDENTITY)
  private Integer id;

  @Version
  @Column(name="version")
  private Integer version;
  
  private Date dob;

  @Column(name = "first_name")
  private String firstName;

  private String gender;

  @Column(name = "last_name")
  private String lastName;

  @Column(name = "middle_name")
  private String middleName;

  private String phone;

  private String ssn;

  @ManyToOne(cascade={PERSIST, MERGE})
  @JoinColumn (name="address_id")
  private Address address;

  @OneToOne(cascade={PERSIST, MERGE})
  @JoinColumn (name="email")
  private User user;

  @OneToMany(targetEntity = Prescription.class)
  @ElementJoinColumn(name="pat_id")
  private Set prescriptions=null;

  @OneToMany (targetEntity=Record.class)
  @ElementJoinColumn(name="pat_id")
  private Set records =null; 
 
  public Patient()
  {
  }

  public Patient(Integer pId)
  {
    setId(pId);
  }

  public Integer getId()
  {
    return this.id;
  }

  public void setId(Integer pId)
  {
    this.id = pId;
  }

  public void setId(String pId)
  {
    this.id = MedRecUtils.str2Integer(pId);
  }

  public Date getDob()
  {
    return this.dob;
  }

  public void setDateOfBirth(Date dob)
  {
    this.dob = dob;
  }

  public void setDob(Date dob)
  {
    this.dob = dob;
  }

  public String getFirstName()
  {
    return this.firstName;
  }

  public void setFirstName(String firstName)
  {
    this.firstName = firstName;
  }

  public String getGender()
  {
    return this.gender;
  }

  public void setGender(String gender)
  {
    this.gender = gender;
  }

  public String getLastName()
  {
    return this.lastName;
  }

  public void setLastName(String lastName)
  {
    this.lastName = lastName;
  }

  public String getMiddleName()
  {
    return this.middleName;
  }

  public void setMiddleName(String middleName)
  {
    this.middleName = middleName;
  }

  public String getPhone()
  {
    return this.phone;
  }

  public void setPhone(String phone)
  {
    this.phone = phone;
  }

  public String getSsn()
  {
    return this.ssn;
  }

  public void setSsn(String ssn)
  {
    this.ssn = ssn;
  }

  public Address getAddress()
  {
    return this.address;
  }

  public void setAddress(Address address)
  {
    this.address = address;
  }

  public User getUser()
  {
    return this.user;
  }

  public void setUser(User user)
  {
    this.user = user;
  }

  public Set getPrescriptions()
  {
    return this.prescriptions;
  }

  public void setPrescriptions(Set prescriptions)
  {
    this.prescriptions = prescriptions;
  }

  public void addPrescription (Prescription prescription){
      if (prescriptions==null)
          prescriptions=new HashSet ();
      
    prescriptions.add( prescription);
  }
  
  public Set getRecords()
  {
    return this.records;
  }

  public void addRecord (Record record){
      if (records==null)
          records=new HashSet ();
    records.add(record);
  }
  
  public void setRecords(Set records)
  {
    this.records = records;
  }

  // Utility
  public String toString()
  {
    StringBuffer str = new StringBuffer();
    str.append("Patient[Id: ").append(id);
    str.append(" | Name: ").append(firstName);
    str.append(" ").append(middleName);
    str.append(" ").append(lastName);
    str.append(" | DOB: ").append(dob);
    str.append(" | Gender: ").append(this.gender);
    str.append(" | SSN: ").append(ssn);
    str.append(" | Phone: ").append(phone);
    str.append(" | Email: ").append(getUser()==null?null:getUser().getUsername());
    str.append(" | ");
    str.append(address == null ? "Address: null" : address.toString());
    str.append(" | "+
        ((user == null) ? "User: null" : user.toString()));
    str.append("]");
    return str.toString();
  }

  public String toStringLite()
  {
    StringBuffer str = new StringBuffer();
    str.append("Patient[Id: ").append(id);
    str.append(" | Name: ").append(firstName);
    str.append(" ").append(middleName);
    str.append(" ").append(lastName);
    str.append(" | SSN: ").append(ssn);
    str.append("]");
    return str.toString();
  }

  public boolean equals(Object other)
  {
    if ((this == other))
      return true;
    if (!(other instanceof Patient))
      return false;
    Patient castOther = (Patient) other;
    return new EqualsBuilder().append(this.getId(), castOther.getId())
        .isEquals();
  }

  public int hashCode()
  {
    return new HashCodeBuilder().append(getId()).toHashCode();
  }
}
