package com.bea.medrec.domain;

import static javax.persistence.GenerationType.IDENTITY;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Version;

/**
 * <p>
 * This class represents information about a prescription.
 * </p>
 * 
 * @author Copyright (c)
 * @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */

/*
 * Declare that this class is a JPA entity. The container will access the
 * fields of the class directly when it needs to read or write persistent
 * values.
 */
@Entity()
public class Prescription implements Serializable {

    @Id()
    @GeneratedValue(strategy = IDENTITY)
    private Integer id;

    @Version
    @Column(name="version")
    private Integer version;
    
    @Column(name = "date_prescribed")
    private Date datePrescribed;

    private String dosage;

    private String drug;

    private String frequency;

    private String instructions;

    @Column(name = "pat_id", insertable = false)
    private Integer patientId;

    @Column(name = "record_id", insertable = false)
    private Integer recordId;

    @Column(name = "refills_remaining")
    private Integer refillsRemaining;

    public Prescription() {
    }

    public Integer getId() {
        return this.id;
    }

    public void setId(Integer pId) {
        this.id = pId;
    }

    public Date getDatePrescribed() {
        return this.datePrescribed;
    }

    public void setDatePrescribed(Date datePrescribed) {
        this.datePrescribed = datePrescribed;
    }

    public String getDosage() {
        return this.dosage;
    }

    public void setDosage(String dosage) {
        this.dosage = dosage;
    }

    public String getDrug() {
        return this.drug;
    }

    public void setDrug(String drug) {
        this.drug = drug;
    }

    public String getFrequency() {
        return this.frequency;
    }

    public void setFrequency(String frequency) {
        this.frequency = frequency;
    }

    public String getInstructions() {
        return this.instructions;
    }

    public void setInstructions(String instructions) {
        this.instructions = instructions;
    }

    public Integer getRefillsRemaining() {
        return this.refillsRemaining;
    }

    public void setRefillsRemaining(Integer refillsRemaining) {
        this.refillsRemaining = refillsRemaining;
    }

    public void setRefillsRemaining(String refillsRemaining) {
        setRefillsRemaining(Integer.parseInt(refillsRemaining));
    }

    public Integer getPatientId() {
        return patientId;
    }

    public void setPatientId(Integer patientId) {
        this.patientId = patientId;
    }

    public void setPatientId(String patientId) {
        setPatientId(Integer.parseInt(patientId));
    }

    public Integer getRecordId() {
        return recordId;
    }

    public void setRecordId(Integer recordId) {
        this.recordId = recordId;
    }

    // Utility
    public String toString() {
        StringBuffer str = new StringBuffer();
        str.append("Prescription [Id: ").append(id);
        str.append(" | PatId: ").append(getPatientId());
        str.append(" | RecId: ").append(getRecordId());
        str.append(" | Calendar: ");
        str.append((datePrescribed == null ? "null" : datePrescribed.toString()));
        str.append(" | Drug: ").append(drug);
        str.append(" | Dosage: ").append(dosage);
        str.append(" | Freq: ").append(frequency);
        str.append(" | Refills: ").append(refillsRemaining);
        str.append(" | Instructions: ").append(instructions);
        str.append("]");
        return str.toString();
    }

}