package com.bea.medrec.domain;

import static javax.persistence.GenerationType.IDENTITY;

import java.io.Serializable;
import java.util.Arrays;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Version;

import kodo.persistence.jdbc.ElementJoinColumn;

/**
 * <p>
 * Represents information about a record. This includes the record's vital
 * signs.
 * </p>
 * 
 * @author Copyright (c)
 * @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */

@NamedQuery(name = "getRecordByPatientId", query = "SELECT r FROM Record r WHERE r.patientId = ?1")

/*
 * Declare that this class is a JPA entity. The container will access the
 * fields of the class directly when it needs to read or write persistent
 * values.
 */
@Entity()
public class Record implements Serializable {

    @Id()
    @GeneratedValue(strategy = IDENTITY)
    private Integer id;

    @Version
    @Column(name="version")
    private Integer version;
    
    private String diagnosis;

    private String notes;

    @Column(name = "record_date")
    private Date recordDate;

    private String symptoms;

    @Column(name = "pat_id", insertable = false)
    private Integer patientId;

    @ManyToOne(cascade = CascadeType.PERSIST)
    @JoinColumn(name = "phys_id")
    private Physician physician;

    @OneToOne(cascade = CascadeType.PERSIST)
    @JoinColumn(name = "vital_id")
    private VitalSigns vitalSigns;

    @OneToMany(targetEntity = Prescription.class, cascade = CascadeType.PERSIST)
    @ElementJoinColumn(name = "record_id")
    private Set prescriptions;

    public Record() {
    }

    public Integer getId() {
        return this.id;
    }

    public void setId(Integer pId) {
        this.id = pId;
    }

    public String getDiagnosis() {
        return this.diagnosis;
    }

    public void setDiagnosis(String diagnosis) {
        this.diagnosis = diagnosis;
    }

    public String getNotes() {
        return this.notes;
    }

    public void setNotes(String notes) {
        this.notes = notes;
    }

    public Date getRecordDate() {
        return this.recordDate;
    }

    public void setRecordDate(Date recordDate) {
        this.recordDate = recordDate;
    }

    public String getSymptoms() {
        return this.symptoms;
    }

    public void setSymptoms(String symptoms) {
        this.symptoms = symptoms;
    }

    public Physician getPhysician() {
        return this.physician;
    }

    public String getPhysicianName() {
        return (this.physician != null ? this.physician.getName() : "");
    }

    public void setPhysician(Physician physician) {
        this.physician = physician;
    }

    public VitalSigns getVitalSigns() {
        return this.vitalSigns;
    }

    public void setVitalSigns(VitalSigns vitalSigns) {
        this.vitalSigns = vitalSigns;
    }

    public Integer getPatientId() {
        return this.patientId;
    }

    public void setPatientId(Integer patientId) {
        this.patientId = patientId;
    }

    public void setPatientId(String patientId) {
        setPatientId(Integer.parseInt(patientId));
    }

    public void addPrescription(Prescription prescription) {
        if (this.prescriptions == null)
            this.prescriptions = new HashSet();

        this.prescriptions.add(prescription);
    }

    public Prescription[] getPrescriptions() {
        if (prescriptions == null)
            return null;
        return (Prescription[]) prescriptions.toArray(new Prescription[prescriptions.size()]);
    }

    public void setPrescriptions(Prescription[] prescriptions) {
        this.prescriptions = new HashSet(Arrays.asList(prescriptions));
    }

    public int getNumOfPrescriptions() {
        return (this.prescriptions == null ? 0 : this.prescriptions.size());
    }

    // Utitily
    public String toString() {
        StringBuffer str = new StringBuffer();
        str.append("RECORD [Id: ").append(id);
        str.append(" | PatId: ").append(patientId);
        str.append(" | DOB: ");
        str.append(this.recordDate == null ? "null" : this.recordDate.toString());
        str.append(" | Syms: ");
        str.append(this.symptoms);
        str.append(" | Diag: ").append(this.diagnosis);
        str.append(" | Notes: ").append(this.notes);
        str.append(" | ");
        str.append(this.physician == null ? "PHYSICIAN: [null]" : this.physician.toString());
        str.append(" | ");
        str.append(getVitalSigns() == null ? "VITALS: [null]" : getVitalSigns().toString());
        str.append(" | ").append(prescriptionsToString());
        str.append("]");

        return str.toString();
    }

    private String prescriptionsToString() {
        StringBuffer str = new StringBuffer();
        if (getNumOfPrescriptions() > 0) {
            str.append("Num of prescriptions: ");
            str.append(getNumOfPrescriptions()).append(" |");
            for (Object prescription1 : prescriptions) {
                Prescription prescription = (Prescription) prescription1;
                str.append(" ").append(prescription.toString());
            }
        } else {
            str.append("Prescription: [0]");
        }
        return str.toString();
    }

}