package com.bea.medrec.domain;

import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Inheritance;
import javax.persistence.InheritanceType;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.Version;

import com.bea.medrec.utils.MedRecUtils;

/**
 * <p>
 * Represents information about a user including username and password.
 * </p>
 * 
 * @author Copyright (c)
 * @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */

/*
 * Declare that this class is a JPA entity. The container will use property
 * access methods (getXxx, setXxx) to read or write persistent values (the
 * default).
 */
@Entity

/*
 * Declare the database table to which this class is mapped.
 */
@Table(name = "medrec_user")
public class User implements Serializable {

    private Integer version;

    private String username;

    private String password;

    private String status;

    private Set groups;

    /** default constructor */
    public User() {
    }

    @Id()
    public String getUsername() {
        return this.username;
    }

    @Version
    @Column(name="version")
    public Integer getVersion() {
        return version;
    }

    public void setVersion(Integer version) {
        this.version = version;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getPassword() {
        return this.password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getStatus() {
        return this.status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    @OneToMany(targetEntity = Group.class)
    public Set getGroups() {
        return this.groups;
    }

    public void setGroups(Set groups) {
        this.groups = groups;
    }

    public void addGroup(Group group) {
        if (this.groups == null)
            this.groups = new HashSet();
        this.groups.add(group);
    }

    /*
     * Prevent JPA from assuming that this is a persistent property. By default,
     * all public properties are persistent.
     */
    @Transient
    public boolean isUserNotEmpty() {
        return (MedRecUtils.isNotEmpty(getStatus()) && MedRecUtils.isNotEmpty(getUsername()) && MedRecUtils.isNotEmpty(getPassword()));
    }

    public String toString() {
        StringBuffer str = new StringBuffer();
        str.append("User[Username: ").append(username);
        str.append(" | Password: ").append(printPassword());
        str.append(" | Status: ").append(status);
        str.append(" | Groups: ");
        if (groups != null && groups.size() > 0) {
            for (Object group : groups) {
                str.append((Group) group).append(" ");
            }
        } else {
            str.append("0");
        }
        str.append("]");
        return str.toString();
    }

    // Utility
    private String printPassword() {
        String pwd = "";
        if (password != null) {
            for (int i = 0; i < password.length(); i++)
                pwd += "*";
        }
        return pwd;
    }

    
}