package com.bea.medrec.dao.orm;

import com.bea.medrec.dao.PatientDao;
import com.bea.medrec.domain.Patient;
import com.bea.medrec.domain.User;
import com.bea.medrec.utils.MedRecLog4jFactory;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import org.apache.log4j.Logger;
import org.springframework.dao.DataAccessException;

public class JpaPatientDao extends BaseDao implements PatientDao {

    private static Logger logger = MedRecLog4jFactory.getLogger(JpaPatientDao.class.getName());

    public List getByEmail(String pEmail) throws DataAccessException {
        User user = new User();
        user.setUsername(pEmail);
        return getByUser(user);
    }

    public Patient getById(Integer pId) throws DataAccessException {
        return getJpaTemplate().find(Patient.class, pId);
    }

    public List getByLastName(String pLastName) throws DataAccessException {
        // Kodo 4.0 EA4 bug.
        // List patients = getJpaTemplate().find(
        // "SELECT p " + "FROM " + Patient.class.getSimpleName() + " p " +
        // "WHERE UPPER(p.lastName) LIKE ?1", pLastName.toUpperCase());

        List patients = getJpaTemplate().find("SELECT p " + "FROM " + Patient.class.getSimpleName() + " p " + "WHERE p.lastName LIKE ?1", pLastName);
        return (patients.isEmpty()) ? Collections.EMPTY_LIST : patients;
    }

    public List getByLastNameFirstName(String pLastName, String pFirstName) throws DataAccessException {
        // Kodo 4.0 EA4 bug.
        // List patients = getJpaTemplate().find(
        // "SELECT p " + "FROM " + Patient.class.getSimpleName() + " p" + "WHERE
        // UPPER(p.lastName) LIKE UPPER(?1) "
        // + "AND UPPER(p.firstName) LIKE UPPER(?2) ", new Object[] { pLastName,
        // pFirstName });

        List patients = getJpaTemplate().find(
                "SELECT p " + "FROM " + Patient.class.getSimpleName() + " p" + "WHERE p.lastName LIKE ?1 " + "AND p.firstName LIKE ?2 ",
                new Object[] { pLastName, pFirstName });

        return (patients.isEmpty()) ? Collections.EMPTY_LIST : patients;
    }

    public List getByLastNameWild(String pLastName) throws DataAccessException {
        return getByLastName("%" + pLastName + "%");
    }

    public Patient getBySsn(String pSsn) throws DataAccessException {
        List patients = getJpaTemplate().find("SELECT p " + "FROM " + Patient.class.getSimpleName() + " p WHERE p.ssn = ?1", pSsn);
        return (patients.isEmpty()) ? null : (Patient) patients.get(0);
    }

    public List getByStatus(String pStatus) throws DataAccessException {

        List patients = getJpaTemplate().find("SELECT p " + "FROM Patient p " + "WHERE p.user.status = ?1", new Object[] { pStatus });

        /*
         * Spring bug: SPR-1737
         */
        // patients = getJpaTemplate().findByNamedQuery("getPatientsByStatus",
        // new Object[] { pStatus });
        return (patients.isEmpty()) ? Collections.EMPTY_LIST : patients;
    }

    public Patient getByUsername(String pUsername) throws DataAccessException {
        User user = new User();
        user.setUsername(pUsername);
        List patients = getByUser(user);

        if (patients.isEmpty())
            return null;

        Patient patient = (Patient) patients.get(0);
        patient.getUser().getUsername();

        return patient;
    }

    public List getByUser(User pUser) throws DataAccessException {
        List patients = getJpaTemplate().find("SELECT p " + "FROM Patient p " + "WHERE p.user.username = ?1", new Object[] { pUser.getUsername() });

        /*
         * Spring bug: SPR-1737
         */
        // patients = getJpaTemplate().findByNamedQuery("getPatientsByUser", new
        // Object[] { pUser.getUsername() });
        return (patients.isEmpty()) ? Collections.EMPTY_LIST : patients;
    }

    public Patient save(Patient pPatient) throws DataAccessException {
        getJpaTemplate().persist(pPatient);
        return pPatient;
    }

    public Patient update(Patient pPatient) throws DataAccessException {
        return getJpaTemplate().merge(pPatient);
    }

}
