package com.bea.medrec.dao.orm;

import com.bea.medrec.dao.RecordDao;
import com.bea.medrec.domain.Prescription;
import com.bea.medrec.domain.Record;
import com.bea.medrec.domain.Patient;
import com.bea.medrec.utils.MedRecLog4jFactory;
import java.util.Collections;
import java.util.List;
import org.apache.log4j.Logger;
import org.springframework.dao.DataAccessException;

/**
 * FIXME
 */
public class JpaRecordDao extends BaseDao implements RecordDao {

    private static Logger logger = MedRecLog4jFactory.getLogger(JpaRecordDao.class.getName());

    public Record getById(Integer pId) throws DataAccessException {
        return getJpaTemplate().find(Record.class, pId);
    }

    public List getByPatientId(Integer pPatientId) throws DataAccessException {
        /*
         * Spring bug: SPR-1737
         */
        // List records = getJpaTemplate().findByNamedQuery(
        // "getRecordByPatientId",
        // new Object[] { pPatientId });
        List records = getJpaTemplate().find("SELECT r FROM Record r WHERE r.patientId = ?1", pPatientId);

        return (records.isEmpty()) ? Collections.EMPTY_LIST : records;
    }

    public Integer save(Record record) throws DataAccessException {
        if (record.getPatientId() == null) {
            throw new IllegalArgumentException("Patient id cannot be null.");
        }

        Patient patient = getJpaTemplate().find(Patient.class, record.getPatientId());
        patient.addRecord(record);

        Prescription[] prescriptions = record.getPrescriptions();
        if (prescriptions != null) {
            for (Prescription prescription : prescriptions) {
                patient.addPrescription(prescription);
            }
        }

        getJpaTemplate().persist(record);

        logger.debug("created record with ID-" + record.getId());
        return record.getId();
    }
}
