package com.bea.medrec.service;

import com.bea.medrec.domain.Mail;
import com.bea.medrec.domain.User;
import com.bea.medrec.exceptions.MedRecException;
import com.bea.medrec.utils.MedRecLog4jFactory;
import org.apache.log4j.Logger;
import org.springframework.mail.MailException;
import org.springframework.mail.MailSender;
import org.springframework.mail.SimpleMailMessage;

/**
 * <p>Service for all functionality related to mail communication.</p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public class MailServiceImpl
    extends BaseService implements MailService {
  private static Logger logger =
    MedRecLog4jFactory.getLogger(MailServiceImpl.class.getName());

  // service beans
  protected MailSender mailSender;
  protected MessagingService messagingService;

  // mail templates
  protected SimpleMailMessage approveMailTemplate;
  protected SimpleMailMessage denyMailTemplate;

  // injection setters
  public void setMailSender(MailSender mailSender) {
    this.mailSender = mailSender;
  }

  public void setMessagingService(MessagingService pMessagingService) {
    this.messagingService = pMessagingService;
  }

  public void setApproveMailTemplate(SimpleMailMessage pApproveMailTemplate) {
    this.approveMailTemplate = pApproveMailTemplate;
  }

  public void setDenyMailTemplate(SimpleMailMessage pDenyMailTemplate) {
    this.denyMailTemplate = pDenyMailTemplate;
  }

    //   P U B L I C   M E T H O D S

    //   C O M P O S E   M A I L
  /**
  * <p>Composes standard MedRec mail message.</p>
  *
  * @param pMail
  */
  public void composeAndSendMail(Mail pMail) throws MedRecException {
    SimpleMailMessage msg = new SimpleMailMessage();
    msg.setFrom(pMail.getFrom());
    msg.setTo(pMail.getTo());
    msg.setSubject(pMail.getSubject());
    msg.setText(pMail.getMessage());
    msg.setSentDate(new java.util.Date());
    messagingService.sendToQueue(msg);
  }

    //   S E N D  A P P R O V E  A C C T   M A I L
  /**
  * <p>Construct and send approve mail message.</p>
  *
  * @param pUser
  */
  public void sendApproveMail(User pUser) throws MedRecException {
    logger.debug("Sending approval mail to "+pUser.toString());
    SimpleMailMessage msg = new SimpleMailMessage(approveMailTemplate);
    msg.setTo(pUser.getUsername());
    msg.setText(msg.getText().replaceFirst("_USERNAME_", pUser.getUsername()));
    msg.setText(msg.getText().replaceFirst("_PASSWORD_", pUser.getPassword()));
    messagingService.sendToQueue(msg);
  }

    //   S E N D  A P P R O V E  A C C T   M A I L
  /**
  * <p>Construct and send approve mail message.</p>
  *
  * @param pUser
  */
  public void sendDenyMail(User pUser) throws MedRecException {
    logger.debug("Sending denial mail to "+pUser.toString());
    SimpleMailMessage msg = new SimpleMailMessage(denyMailTemplate);
    msg.setTo(pUser.getUsername());
    messagingService.sendToQueue(msg);
  }

    //   S E N D  M A I L
  /**
  * <p>Send mail message.</p>
  *
  * @param pMail
  */
  public void sendMail(SimpleMailMessage pMail) throws MedRecException {
    SimpleMailMessage msg = new SimpleMailMessage();
    msg.setSentDate(new java.util.Date());
    try {
      mailSender.send(msg);
    } catch (MailException ex) {
      logger.error("Exception occurred: "+ex.getMessage(), ex);
      throw new MedRecException("Unable to send mail: "+ex.getMessage(), ex);
    }
  }
}
