package com.bea.medrec.service;

import com.bea.medrec.domain.*;
import com.bea.medrec.exceptions.MedRecException;
import java.io.File;
import java.util.List;
import org.springframework.mail.SimpleMailMessage;

/**
 * FIXME
 */
public class MedRecServiceFacadeImpl implements MedRecServiceFacade {

  protected AdminService adminService;
  protected PatientService patientService;
  protected RecordService recordService;
  protected MailService mailService;
  protected MessagingService messagingService;
  protected RecordXmlProcessorService recordXmlProcessorService;

  // injection setters
  public void setAdminService(AdminService adminService) {
    this.adminService = adminService;
  }

  public void setMailService(MailService pMailService) {
    this.mailService = pMailService;
  }

  public void setMessagingService(MessagingService pMessagingService) {
    this.messagingService = pMessagingService;
  }

  public void setPatientService(PatientService patientService) {
    this.patientService = patientService;
  }

  public void setRecordService(RecordService recordService) {
    this.recordService = recordService;
  }

  public void setRecordXmlProcessorService(
      RecordXmlProcessorService pRecordXmlProcessorService) {
    this.recordXmlProcessorService = pRecordXmlProcessorService;
  }

  // business methods
  // admin service
  public Integer createPatientAccount(User pUser, Patient pPatient)
      throws MedRecException {
    return adminService.createPatientAccount(pUser, pPatient);
  }

  public Patient createPatientAccount(Patient pPatient)
      throws MedRecException {
    return adminService.createPatientAccount(pPatient);
  }

  public void saveMedicalRecord(List<MedicalRecord> pMedicalRecords)
      throws MedRecException {
     adminService.saveMedicalRecord(pMedicalRecords);
  }

  // mail service
  public void sendMail(SimpleMailMessage pMail) throws MedRecException {
    mailService.sendMail(pMail);
  }

  public void composeAndSendMail(Mail pMail)
      throws MedRecException {
    mailService.composeAndSendMail(pMail);
  }

  // messaging service
  public void sendToQueue(SimpleMailMessage pMail) throws MedRecException {
    messagingService.sendToQueue(pMail);
  }

  public void sendToQueue(Registration pRegistration) throws MedRecException {
    messagingService.sendToQueue(pRegistration);
  }

  public void sendToQueue(File pUploadFile) throws MedRecException {
    messagingService.sendToQueue(pUploadFile);
  }

  // patient service
  public Patient getPatient(Patient pPatient) throws MedRecException {
    return patientService.getPatient(pPatient);
  }

  public List getPatientByWildLastName(Patient pPatient)
      throws MedRecException {
    return patientService.getPatientByWildLastName(pPatient);
  }

  public void processNewRegistration(Registration pRegistration)
      throws MedRecException {
    patientService.processNewRegistration(pRegistration);
  }

  public Patient savePatient(Patient pPatient) throws MedRecException {
    return patientService.savePatient(pPatient);
  }

  // record service
  public Record getRecord(Integer pRecordId) throws MedRecException {
    return recordService.getRecord(pRecordId);
  }

  public RecordsSummary getRecordsSummary(Patient pPatient)
      throws MedRecException {
    return recordService.getRecordsSummary(pPatient);
  }

  public Record saveRecord(Record pRecord) throws MedRecException {
    return recordService.saveRecord(pRecord);
  }

  public void saveRecords(List pRecord, Patient pPatient)
      throws MedRecException {
    recordService.saveRecords(pRecord, pPatient);
  }

  // record upload
  public void saveXmlRecord(String pFilename) throws MedRecException {
    recordXmlProcessorService.saveXmlRecord(pFilename);
  }
}
