package com.bea.medrec.service;

import com.bea.medrec.domain.MedicalRecord;
import com.bea.medrec.domain.XmlImportFile;
import com.bea.medrec.exceptions.MedRecException;
import com.bea.medrec.utils.MedRecLog4jFactory;
import com.bea.medrec.utils.XmlFileFilter;
import java.io.*;
import java.text.SimpleDateFormat;
import java.util.*;
import org.apache.log4j.Logger;
import org.apache.xmlbeans.XmlException;

/**
 * FIXME
 */
public class RecordXmlProcessorServiceImpl
    extends BaseService implements RecordXmlProcessorService {

  private static Logger logger =
      MedRecLog4jFactory.getLogger(RecordXmlProcessorServiceImpl.class.getName());

  // service bean
  protected AdminService adminService;

  // injected variables
  protected RecordXmlConvertor recordXmlConvertor;
  protected String uploadLocation;

  // injected setters
  public void setAdminService(AdminService pAdminService){
    this.adminService = pAdminService;
  }

  public void setRecordXmlConvertor(RecordXmlConvertor pRecordXmlConvertor){
    this.recordXmlConvertor = pRecordXmlConvertor;
  }

  public void setUploadLocation(String pUploadLocation){
    this.uploadLocation = pUploadLocation;
  }

  //  G E T   P E N D I N G,   I N C O M I N G   X M L   F I L E S
  /**
   * <p>Get pending, incoming xml files containing new patients and
   * their medical record.</p>
   *
   * @return Collection  Collection of XmlImportFile objects.
   */
  public Collection<Object> getIncomingXmlFiles() {
    // Declare local variables.
    Collection<Object> col = new ArrayList<Object>();

    // if the log4j-init-file is not set, then no point in trying
    if (uploadLocation != null) {
      File xmlDir = new File(uploadLocation);
      if (xmlDir.isDirectory()) {
        FilenameFilter filter = new XmlFileFilter();
        File[] files = xmlDir.listFiles(filter);
        for (File file : files) {
          Calendar cal = new GregorianCalendar();
          cal.setTimeInMillis(file.lastModified());
          XmlImportFile xmlFile = new XmlImportFile(file.getName(),
              uploadLocation, cal, file.length());
          logger.debug(xmlFile.toString());
          col.add(xmlFile);
        }
      }
    }
    return col;
  }

  //   S A V E   X M L    R E C O R D
  /**
   * <p>Parses Xml stream into MedRec value objects.
   * Stores resultant objects.</p>
   *
   * @param pBis
   * @throws MedRecException
   */
  public void saveXmlRecord(BufferedInputStream pBis)
      throws MedRecException {
    logger.info("Parsing xml and saving resultant.");

    // Declare local variables.
    List<MedicalRecord> medicalRecords = new ArrayList<MedicalRecord>();

    logger.debug("Parsing xml doc.");
    try {
      recordXmlConvertor.parse(pBis);
    } catch (IOException e) {
      logger.error("Exception occurred: "+e.getMessage(), e);
      throw new MedRecException("Unable to parse medical record xml file: "+
          e.getMessage(), e);
    } catch (XmlException xe) {
      logger.error(xe);
      throw new MedRecException("Unable to parse medical record xml file: "+
          xe.getMessage(), xe);
    }

    logger.debug("Getting MedicalRecords collection.");
    medicalRecords.addAll(recordXmlConvertor.getMedicalRecords());
    if (logger.isDebugEnabled()) printMedicalRecords(medicalRecords);
    adminService.saveMedicalRecord(medicalRecords);
  }

  /**
   * <p>Parses given Xml file found in xml.incoming System property
   * into MedRec value objects.  Stores resultant objects.</p>
   *
   * @param pFilename
   * @throws MedRecException
   */
  public void saveXmlRecord(String pFilename)
      throws MedRecException {
    logger.info("Parsing xml file: "+pFilename);

    // Declare local variables.
    File xmlFile = null;
    File archivedFile = null;
    FileInputStream fis = null;

    xmlFile = new File(uploadLocation+"/"+pFilename);
    logger.debug("Xml filepath: "+xmlFile.getAbsolutePath());

    if (!xmlFile.exists() || !xmlFile.isFile())
      throw new MedRecException("File not found.");

    try {
      fis = new FileInputStream(xmlFile);
      saveXmlRecord(new BufferedInputStream(fis));
    } catch (FileNotFoundException fe) {
      logger.error(fe);
      throw new MedRecException("Unable to open file "+pFilename, fe);
    } finally {
      try {
        fis.close();
      } catch (IOException e) {
        logger.warn("Unable to close file "+pFilename, e);

      }
    }

    archivedFile = new File(uploadLocation+"/"+pFilename+"_"+
        getDateTimeStr());
    xmlFile.renameTo(archivedFile);

  }

  //   P R I V A T E   M E T H O D S
  /**
   * <p>Prints contents of medical record collection.</p>
   */
  private void printMedicalRecords(Collection<MedicalRecord> pMedRecCol) {
    // Declare local variables.
    Iterator itr = null;
    MedicalRecord medicalRecord = null;

    itr = pMedRecCol.iterator();
    while (itr.hasNext()) {
      medicalRecord = (MedicalRecord) itr.next();
      logger.debug("******* Medical Record **********");
      logger.debug(medicalRecord.toString());
    }
  }

  /**
   * <p>Returns date string - yyMMddHHmmss.</p>
   */
  private String getDateTimeStr() {
    SimpleDateFormat dateFormat = null;
    dateFormat = new SimpleDateFormat("yyMMddHHmmss");
    return dateFormat.format(new Date());

  }
}
