package com.bea.medrec.web.admin.actions;

import com.bea.medrec.utils.MedRecLog4jFactory;
import com.bea.medrec.web.beans.UserBean;
import com.bea.medrec.web.exceptions.ClientException;
import com.bea.medrec.web.utils.MedRecWebAppUtils;
import java.util.Locale;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.apache.log4j.Logger;
import org.apache.struts.action.*;
import weblogic.servlet.security.ServletAuthentication;

/**
 * <p>Admin Login service.  Handles all request during the Admin login
 * process.</p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public class AdminLoginAction extends AdminBaseAction {

  private static Logger logger =
      MedRecLog4jFactory.getLogger(AdminLoginAction.class.getName());

 /**
  * <p>Process the specified HTTP request, and create the corresponding HTTP
  * response (or forward to another web component that will create it).
  * Return an <code>ActionForward</code> instance describing where and how
  * control should be forwarded.
  * <br>
  * Handles incoming login requests.
  * </p>
  *
  * @param mapping  The ActionMapping used to select this instance
  * @param form  The optional ActionForm bean for this request (if any)
  * @param request  The HTTP request we are processing
  * @param response  The HTTP response we are creating
  */
  public ActionForward executeAction(ActionMapping mapping,
                                     ActionForm form,
                                     HttpServletRequest request,
                                     HttpServletResponse response)
    throws ClientException
  {
    // Set user's locale.
    setupLocale(request);

    // Declare and initial local variables.
    UserBean user = (UserBean)form;
    String action = request.getParameter(ACTION);
    String loginSubmit = null;

    // Cancel login.  Redirect to start page.
    if (isCancelled(request)) {
      logger.info("Cancel login.");
      form.reset(mapping, request);
      ServletAuthentication.invalidateAll(request);
      // Return to MedRec start page.
      return new ActionForward("medrec.startpage", true);
    }

    // Login processing.
    loginSubmit = getMessage(request, "button.Login");
    logger.debug("Action: "+action);
    logger.debug("Button Message: "+loginSubmit);
    if (MedRecWebAppUtils.isNotEmpty(action) && action.equals(loginSubmit)) {
      return authenticate(user, mapping, request, response);
    }

    // First time thru.
    return mapping.findForward("login.home");
  }

 /**
  * <p>This method authenticates a given user containg a username and password.
  * Since MedRec contains an Admin and Patient appplication and
  * each application has its own specific authentication provider. The Admin
  * application uses WebLogic's DefaultAuthenticator which stores usernames
  * and passwords within an LDAP database.</p>
  */
  private ActionForward authenticate(UserBean user,
                                     ActionMapping mapping,
                                     HttpServletRequest request,
                                     HttpServletResponse response) {

    // Declare local variables.
    ActionForward forward = null;

    Locale currentLocale = getLocale(request);
    ServletAuthentication.invalidateAll(request);
    setLocale(request, currentLocale);

    // Returns an int value for AUTHENTICATED or FAILED_AUTHENTICATION
    // after using the username and password to authenticate the user
    // and setting that user information into the session.
    int auth = ServletAuthentication.weak(user.getUsername(),
        user.getPassword(), request, response);

    // Check auth return value.
    if (auth == ServletAuthentication.AUTHENTICATED
        && request.isUserInRole(MEDREC_ADMIN_ROLE)) {
      logger.info("Authentication success!");

      // Create new session.
      HttpSession session = request.getSession(true);

      // Set user on session to be used throughout the app.
      UserBean admin = new UserBean();
      admin.setUsername(user.getUsername());
      session.setAttribute(ADMIN_BEAN, admin);

      forward = getRedirectPage(request, mapping);
    }
    else {
      logger.info("Authentication failed!");

      // Reset login values.
      user.reset();

      // Create action error - invalid username and/or password.
      ActionMessages errorMsgs = new ActionMessages();
      errorMsgs.add("invalidLogin",
          new ActionMessage("invalid.username.password"));
      saveErrors(request, errorMsgs);

      // Set redirect to login page.
      forward = mapping.findForward("login.failure");
    }

    // Log where we are going next.
    logger.info("Redirecting to: "+forward.getPath());
    return forward;
  }
}