package com.bea.medrec.web.admin.actions;

import com.bea.medrec.domain.Mail;
import com.bea.medrec.domain.User;
import com.bea.medrec.domain.Patient;

import com.bea.medrec.exceptions.MedRecException;
import com.bea.medrec.utils.MedRecLog4jFactory;
import com.bea.medrec.web.beans.PatientBean;
import com.bea.medrec.web.exceptions.ClientException;
import java.util.HashMap;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

/**
 * <p>Patient registration approval service.
 * Handles requests to approve a patient registration.</p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public class ApprovePatientRequestAction extends AdminBaseLookupDispatchAction {
  private static Logger logger =
      MedRecLog4jFactory.getLogger(ApprovePatientRequestAction.class.getName());

 /**
  * <p>Determines method calling based on select submit button.</p>
  */
  protected Map getKeyMethodMap() {
    Map<String,String> map = new HashMap<String,String>();
    map.put("button.Approve", "approve");
    map.put("button.Deny", "deny");
    map.put("button.Cancel", "cancel");
    return map;
  }

 /**
  * <p>Default action method.</p>
  *
  * @return ActionForward
  */
  public ActionForward defaultMethod(ActionMapping mapping,
                                     ActionForm form,
                                     HttpServletRequest request,
                                     HttpServletResponse response)
    throws Exception
  {
    return mapping.findForward("patient.approval.success");
  }

 /**
  * <p>User selected patient approve button.</p>
  *
  * @return ActionForward
  */
  public ActionForward approve(ActionMapping mapping,
                            ActionForm form,
                            HttpServletRequest request,
                            HttpServletResponse response)
    throws ClientException, Exception
  {
    // Declare and initialize local variables.
    Patient patient =
      (Patient)getSessionAttribute(request, PATIENT);
    
   try {
      medRecClientServiceFacade.activateAccount(patient.getUser());
    } catch (MedRecException e) {
      throwClientException(e, mapping, "patient.approval.failure");
    }
    return mapping.findForward("patient.approval.success");
  }

 /**
  * <p>User selected cancel button.</p>
  *
  * @return ActionForward
  */
  public ActionForward cancel(ActionMapping mapping,
                              ActionForm form,
                              HttpServletRequest request,
                              HttpServletResponse response)
    throws Exception
  {
    logger.info("Cancel approve patient registration.");
    return mapping.findForward("patient.approval.success");
  }

 /**
  * <p>User selected patient deny button.</p>
  *
  * @return ActionForward
  */
  public ActionForward deny(ActionMapping mapping,
                            ActionForm form,
                            HttpServletRequest request,
                            HttpServletResponse response)
    throws ClientException, Exception
  {
    Patient patient =
      (Patient)getSessionAttribute(request, PATIENT);
    
    try {
      medRecClientServiceFacade.denyAccountStatus(patient.getUser());
    } catch (MedRecException e) {
      throwClientException(e, mapping, "patient.approval.failure");
    }
    return mapping.findForward("patient.approval.success");
  }

}
