package com.bea.medrec.web.admin.actions;

import com.bea.medrec.exceptions.MedRecException;
import com.bea.medrec.utils.MedRecLog4jFactory;
import com.bea.medrec.web.admin.beans.DiagnosticsBean;
import com.bea.medrec.web.exceptions.ClientException;
import java.lang.reflect.Field;
import java.util.Arrays;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Map;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import weblogic.diagnostics.accessor.ColumnInfo;
import weblogic.diagnostics.accessor.LogTypes;
import weblogic.logging.Severities;

/**
 * Handles retrieving and organizing diagnotics data.
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public class DiagnosticsAction extends AdminBaseLookupDispatchAction {

  private static Logger logger =
      MedRecLog4jFactory.getLogger(DiagnosticsAction.class.getName());

  private String timeInterval = "";
  private String numOfIntervals = "";

  public void setTimeInterval(String pTimeInterval) {
    timeInterval = pTimeInterval;
  }

  public void setNumOfIntervals(String pNumOfIntervals) {
    numOfIntervals = pNumOfIntervals;
  }

  public ActionForward execute(ActionMapping mapping,
                               ActionForm form,
                               HttpServletRequest request,
                               HttpServletResponse response)
    throws ClientException, Exception
  {
    logger.debug("method mapping="+
        request.getParameter(mapping.getParameter()));
    if (request.getParameter(mapping.getParameter()) == null) {
      return defaultMethod(mapping, form, request, response);
    } else
      return super.execute(mapping, form, request, response);
  }

 /**
  * <p>Determines method calling based on select submit button.</p>
  */
  protected Map getKeyMethodMap() {
    Map<String,String> map = new HashMap<String,String>();
    map.put("button.Logs", "getLogs");
    map.put("button.Cancel", "cancel");
    return map;
  }

 /**
  * <p>Default action method.</p>
  *
  * @return ActionForward
  */
  public ActionForward defaultMethod(ActionMapping mapping,
                                     ActionForm form,
                                     HttpServletRequest request,
                                     HttpServletResponse response)
    throws Exception
  {
    return loadDiagnosticsPage(mapping, form);
  }

  private ActionForward loadDiagnosticsPage(ActionMapping mapping,
                                           ActionForm form)
    throws ClientException, Exception
  {
    // local variables
    DiagnosticsBean diagnosticsBean = (DiagnosticsBean)form;
    if (diagnosticsBean == null) diagnosticsBean= new DiagnosticsBean();

    // create collection of log type options
    setLogNames(diagnosticsBean);

    // create list of time intervals
    setTimeSpan(diagnosticsBean);

    // create list of message severity
    setSeverity(diagnosticsBean);

    // Redirect to home view.
    return mapping.findForward("diagnostics.home");
  }

  private void setLogNames(DiagnosticsBean diagnosticsBean)
      throws Exception {
    String[] names = medRecClientServiceFacade.getLogTypes();
    Arrays.sort(names);
    for (String name : names) {
      if (name.contains("pop_up_only"))
        continue;
      diagnosticsBean.addLogType(name, name);
    }
  }

  private void setTimeSpan(DiagnosticsBean diagnosticsBean)
      throws NamingException {
        diagnosticsBean.addTimeSpan("All", "0");
    Context initCtx = new InitialContext();
    int intervalSpan = (Integer) initCtx.lookup(this.timeInterval);
    int numOfIntervals = (Integer) initCtx.lookup(this.numOfIntervals);
    int tmpInterval = 0;
    for (int j=0; j<numOfIntervals; j++) {
      tmpInterval += intervalSpan;
      diagnosticsBean.addTimeSpan(String.valueOf(tmpInterval),
          String.valueOf(tmpInterval));
    }
  }

  private void setSeverity(DiagnosticsBean diagnosticsBean)
      throws IllegalAccessException {
    Field[] msgFields;
    diagnosticsBean.addMsgSeverity("All","All");
    msgFields = Severities.class.getFields();
    sortFields(msgFields);
    for (Field msgField : msgFields) {
      String name = msgField.getName();
      if (!name.endsWith("_TEXT")) continue;
      diagnosticsBean.addMsgSeverity((String) msgField.get(name),
          (String) msgField.get(name));
    }
  }

  public ActionForward getLogs(ActionMapping mapping,
                               ActionForm form,
                               HttpServletRequest request,
                               HttpServletResponse response)
    throws ClientException, Exception
  {
    // local variables
    DiagnosticsBean diagnosticsBean = (DiagnosticsBean)form;
    logger.debug(diagnosticsBean.toString());
    ColumnInfo[] colInfo = null;
    StringBuffer queryStr = new StringBuffer();

    // construct query string for msg severity
    queryStr.append(getMsgSeverityQueryStr(diagnosticsBean));

    // construct query string for msg content search
    String searchStr = getSearchQueryStr(diagnosticsBean);
    if (isNotEmpty(searchStr) && isNotEmpty(queryStr.toString())) {
      queryStr.append(" AND ");
      queryStr.append(searchStr);
    } else if (isNotEmpty(searchStr) && isEmpty(queryStr.toString())) {
      queryStr.append(searchStr);
    }


    logger.debug("Final query string: "+queryStr);

    // get column names
    Object[] rows = new java.lang.Object[0];
    try {
      colInfo = medRecClientServiceFacade.getLogColumnInfo(
          diagnosticsBean.getLogType());
      rows = medRecClientServiceFacade.getLogRows(
              diagnosticsBean.getLogType(), queryStr.toString());
    } catch (MedRecException e) {
      throwClientException(e, mapping, "diagnostics.home");
    }

    // place objects on request to be render by the view
    logger.debug("Preparing output");
    request.setAttribute(AdminConstants.LOG_TYPE,
        diagnosticsBean.getLogType());
    request.setAttribute(AdminConstants.LOG_COLUMNS, colInfo);
    request.setAttribute(AdminConstants.LOG_RECORDS, rows);

    // Redirect to home view.
    return mapping.findForward("diagnostics.logs");
  }

  // construct query string for msg severity
  protected String getMsgSeverityQueryStr(DiagnosticsBean diagnosticsBean) {
    String queryStr = "";
    if (isNotEmpty(diagnosticsBean.getMsgSeverity())
        && !diagnosticsBean.getMsgSeverity().equals("All")
        && (diagnosticsBean.getLogType().equals(LogTypes.SERVER_LOG)
            || diagnosticsBean.getLogType().equals(LogTypes.DOMAIN_LOG))) {
      queryStr += "SEVERITY = '"+diagnosticsBean.getMsgSeverity()+"'";
    }
    return queryStr;
  }

  // construct query string for msg content search
  protected String getSearchQueryStr(DiagnosticsBean diagnosticsBean) {
    String queryStr = "";
    if (isNotEmpty(diagnosticsBean.getSearchCriteria())
        && (diagnosticsBean.getLogType().equals(LogTypes.SERVER_LOG)
            || diagnosticsBean.getLogType().equals(LogTypes.DOMAIN_LOG))) {
      queryStr += "MESSAGE LIKE '%"+diagnosticsBean.getSearchCriteria()+"%'";
    }
    return queryStr;
  }

 /**
  * <p>User selected cancel button.</p>
  *
  * @return ActionForward
  */
  public ActionForward cancel(ActionMapping mapping,
                              ActionForm form,
                              HttpServletRequest request,
                              HttpServletResponse response)
    throws Exception
  {
    logger.info("Cancel log retrieval.");
    return mapping.findForward("admin.home");
  }

  // sort view fields
  private void sortFields(Field[] fields) {
    Arrays.sort(fields,
        new Comparator() {
            public int compare(Object o1, Object o2) {
              String fname1 = ((Field)o1).getName();
              String fname2 = ((Field)o2).getName();
              int n1=fname1.length(), n2=fname2.length();
              for (int i1=0, i2=0; i1<n1 && i2<n2; i1++, i2++) {
                  char c1 = fname1.charAt(i1);
                  char c2 = fname2.charAt(i2);
                  if (c1 != c2) {
                      c1 = Character.toUpperCase(c1);
                      c2 = Character.toUpperCase(c2);
                      if (c1 != c2) {
                          c1 = Character.toLowerCase(c1);
                          c2 = Character.toLowerCase(c2);
                          if (c1 != c2) {
                              return c1 - c2;
                          }
                      }
                  }
                }
                return n1 - n2;
              }
          });
  }
}