package com.bea.medrec.web.admin.actions;

import com.bea.medrec.domain.Patient;
import com.bea.medrec.exceptions.MedRecException;
import com.bea.medrec.utils.MedRecLog4jFactory;
import com.bea.medrec.web.admin.beans.PatientApprovalBean;
import com.bea.medrec.web.exceptions.ClientException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

/**
 * <p>Controller displaying pending registration requests.</p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public class ViewRequestsAction extends AdminBaseAction {

  private static Logger logger =
      MedRecLog4jFactory.getLogger(ViewRequestsAction.class.getName());

 /**
  * <p>Process the specified HTTP request, and create the corresponding HTTP
  * response (or forward to another web component that will create it).
  * Return an <code>ActionForward</code> instance describing where and how
  * control should be forwarded.
  * <br>
  * Displays pending registration requests.
  * </p>
  *
  * @param mapping  The ActionMapping used to select this instance
  * @param form  The optional ActionForm bean for this request (if any)
  * @param request  The HTTP request we are processing
  * @param response  The HTTP response we are creating
  */
  public ActionForward executeAction(ActionMapping mapping,
                                     ActionForm form,
                                     HttpServletRequest request,
                                     HttpServletResponse response)
    throws ClientException, Exception {

    try {
      // Retrieve new patients to approve/deny.
      Collection col = medRecClientServiceFacade.getNewPatients();
      Collection patientApprovalBeans =
          toPatientApprovalBeanCollection(col);
      logger.debug("Num of Patients to Approve: "+patientApprovalBeans.size());
      request.setAttribute("PatientApprovalBeans", patientApprovalBeans);
    }
    catch(MedRecException e) {
      throwClientException(e, mapping, "home");
    }

    return mapping.findForward("view.requests");
  }

  //   P A T I E N T   A P P R O V A L
  /**
   * <p>Converts a collection of patient approval presentation beans to
   * a collection of patient approval value objects.</p>
   *
   * @param patients Collection of Patient VOs
   * @return Collection   Collection of Patient Beans
   */
  public Collection toPatientApprovalBeanCollection(Collection patients) {
    Collection array = new ArrayList();
    if (patients != null) {
      Iterator itr = patients.iterator();
      while (itr.hasNext()) {
        Patient patient = (Patient) itr.next();
        PatientApprovalBean approval = new PatientApprovalBean(patient.getId(),
            patient.getLastName(), patient.getFirstName());
        array.add(approval);
      }
    }
    return array;
  }

}