package com.bea.medrec.web.beans;

import com.bea.medrec.domain.Address;
import com.bea.medrec.web.utils.MedRecWebAppUtils;

/**
 * <p>Form bean for addresses.
 * This form has the following fields,
 * with default values in square brackets:
 * <ul>
 * <li><b>street1</b> - Entered street name 1 value
 * <li><b>street2</b> - Entered street name 2 value
 * <li><b>city</b> - Entered city value
 * <li><b>state</b> - Entered state value
 * <li><b>zipCode</b> - Entered zip code value
 * <li><b>country</b> - Entered country value
 * </ul>
 * </p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public final class AddressBean extends BaseBean {

  // Instance Variables
  private String street1 = null;
  private String street2 = null;
  private String city = null;
  private String state = null;
  private String zipCode = null;
  private String country = null;
  
  // Constructors
  public AddressBean() {
  }

  public AddressBean(Address address) {
    super.setId(address.getId());
    this.street1 = address.getStreet1();
    this.street2 = address.getStreet2();
    this.city = address.getCity();
    this.state = address.getState();
    this.zipCode = address.getZip();
    this.country = address.getCountry();
  }

  public AddressBean(String id,
                     String street1,
                     String street2,
                     String city,
                     String state,
                     String zipCode,
                     String country) {
    super.setId(id);
    this.street1 = street1;
    this.street2 = street2;
    this.city = city;
    this.state = state;
    this.zipCode = zipCode;
    this.country = country;
  }

  public AddressBean(Integer id,
                     String street1,
                     String street2,
                     String city,
                     String state,
                     String zipCode,
                     String country) {
    super.setId(id);
    this.street1 = street1;
    this.street2 = street2;
    this.city = city;
    this.state = state;
    this.zipCode = zipCode;
    this.country = country;
  }

  public String getStreet1() {
    return this.street1;
  }

  public String getStreet2() {
    return this.street2;
  }

  public String getCity() {
    return this.city;
  }

  public String getState() {
    return this.state;
  }

  public String getZipCode() {
    return this.zipCode;
  }

  public String getCountry() {
    return this.country;
  }

  public void setStreet1(String street1) {
    this.street1 = MedRecWebAppUtils.cleanParam(street1);
  }

  public void setStreet2(String street2) {
    this.street2 = MedRecWebAppUtils.cleanParam(street2);
  }

  public void setCity(String city) {
    this.city = MedRecWebAppUtils.cleanParam(city);
  }

  public void setState(String state) {
    this.state = MedRecWebAppUtils.cleanParam(state);
  }

  public void setZipCode(String zipCode) {
    this.zipCode = MedRecWebAppUtils.cleanParam(zipCode);
  }

  public void setCountry(String country) {
    this.country = MedRecWebAppUtils.cleanParam(country);
  }

  // Public Methods
  public void reset() {
    this.street1 = "";
    this.street2 = "";
    this.city = "";
    this.state = "";
    this.zipCode = "";
    this.country = "";
  }

  /**
   * <p>Converts address presentation bean to address value object.</p>
   *
   * @return Address
   */
  public Address toAddress() {
    Address address = new Address();
    
    return exportChanges (address);
  }

  public Address exportChanges (Address address){
    //address.setId(getId());
    address.setStreet1(getStreet1());
    address.setStreet2(getStreet2());
    address.setCity(getCity());
    address.setState(getState());
    address.setZip(getZipCode());
    address.setCountry(getCountry());
    return address;
  }

  public String toString() {
    StringBuffer str = new StringBuffer();
    str.append("Address[Id: " + getId());
    str.append(" | Street1: " + street1);
    str.append(" | Street2: " + street2);
    str.append(" | City: " + city);
    str.append(" | State: " + state);
    str.append(" | ZipCode: " + zipCode);
    str.append(" | Country: " + country);
    str.append("]");

    return str.toString();
  }
}
