package com.bea.medrec.web.beans;

import com.bea.medrec.utils.MedRecLog4jFactory;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import org.apache.log4j.Logger;
import org.apache.struts.validator.ValidatorForm;

/**
 * <p>Base bean encapsulating common bean attributes and functionality.</p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public abstract class BaseBean extends ValidatorForm {
  private static Logger logger =
      MedRecLog4jFactory.getLogger(BaseBean.class.getName());

  // Instance Variables
  private String action = "";
  private String id = "";

  public BaseBean() {
  }

  // Getters
  public String getAction() {
    return this.action;
  }

  public String getId() {
    return this.id;
  }

  // Setters
  public void setAction(String action) {
    this.action = action;
  }

  public void setId(String id) {
    this.id = id;
  }

  public void setId(Integer id) {
    this.id = toStr(id);
  }

  // Utility
  protected String setDateStr(String str) {
    SimpleDateFormat sdf = null;
    String dateStr = "";
    try {
      sdf = new SimpleDateFormat("MM/dd/yyyy");
      Date d = sdf.parse(str);
      dateStr = sdf.format(d);
    } catch (ParseException e) {
    }
    return dateStr;
  }

  protected static String toStr(Object obj) {
    if (obj != null)
      return obj.toString();
    else
      return null;
  }

  // Validation
  /**
   * <p>String null check.</p>
   *
   * @param str
   */
  protected boolean isNotEmpty(String str) {
    return str != null && str.length() > 0;
  }

  /**
   * <p>String null check.</p>
   *
   * @param str
   */
  protected boolean isEmpty(String str) {
    return !(isNotEmpty(str));
  }

  protected Integer str2Integer(String str) {
    logger.debug("Converting "+str+" to Integer");
    Integer tempInt = null;
    try {
      if (!isEmpty(str))
        tempInt = Integer.valueOf(str);
    } catch (NumberFormatException e) {
    }
    return tempInt;
  }

         //   D A T E   M A N I P U L A T I O N
 /**
  * <p>String representation of a calendar. Format: MM/DD/YYYY</p>
  *
  * @param pCalendar
  * @return String
  */
  protected String getDisplayDate(Calendar pCalendar) {
    SimpleDateFormat format = new SimpleDateFormat("MM/dd/yyyy");
    if (pCalendar != null) return format.format(pCalendar.getTime());
    else return "";
  }

  protected String getDisplayDate(java.util.Date pDate) {
    Calendar cal = Calendar.getInstance();
    cal.setTime(pDate);
    return getDisplayDate(cal);
  }

  public Date str2Date(String str) {
    java.util.Date date = null;
    if (!isEmpty(str)) {
      try {
        SimpleDateFormat sdf = new SimpleDateFormat("MM/dd/yyyy");
        date = sdf.parse(str);
      }
      catch(ParseException e) {   }
    }
    return date;
  }

 /**
  * <p>Convert string representation of a date to calendar.</p>
  *
  * @param str
  * @return Calendar
  */
  protected Calendar str2Calendar(String str) {
   logger.debug("Converting "+str+" to Calendar");
    Calendar cal = null;
    if (!isEmpty(str)) {
      try {
        SimpleDateFormat sdf = new SimpleDateFormat("MM/dd/yyyy");
        java.util.Date d = sdf.parse(str);
        cal = Calendar.getInstance();
        cal.setTime(d);
      }
      catch(ParseException e) {   }
    }
    return cal;
  }

 /**
  * <p>Check for valid email.  Format only.  Format: a@a.aaa</p>
  *
  * @param email
  * @return boolean
  */
  protected boolean isValidEmail(String email) {
    boolean valid = true;
    if (email == null) {
      valid = false;
      logger.warn("Email: invalid");
    }
    if (valid) {
      String invalid[] = {" ","#","&",":",";","^","%","!","*","(",")"};
      for (String aInvalid : invalid) {
        if (email.indexOf(aInvalid) >= 0) {
          valid = false;
          logger.warn("Email: invalid");
        }
      }
    }
    if (valid) {
      int atFound  = email.indexOf("@");
      int dotFound = email.indexOf(".", atFound);

      if (atFound < 0 || dotFound < 0 || atFound+1 == dotFound) {
        valid = false;
        logger.warn("Email: invalid");
      }
    }
    return valid;
  }

  /**
   * <p>Check for valid social security number. Format: 999999999</p>
   *
   * @param ssn
   * @return boolean
   */
  protected boolean isValidSsn(String ssn) {
    boolean valid = true;
    if (isEmpty(ssn)) {
      logger.warn("SSN: invalid");
      valid = false;
    } else if (ssn.length() != 9) {
      logger.warn("SSN: invalid");
      valid = false;
    }
    return valid;
  }
}
