package com.bea.medrec.web.beans;

import com.bea.medrec.domain.Prescription;
import com.bea.medrec.domain.Record;
import com.bea.medrec.web.utils.MedRecWebAppUtils;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.validator.Resources;

/**
 * <p>Form bean for the user record pages.
 * This form has the following fields,
 * with default values in square brackets:
 * <ul>
 * <li><b>patientId</b> - Hidden patientId value
 * <li><b>physicianId</b> - Hidden firstName value
 * <li><b>symptoms</b> - Entered symptoms value
 * <li><b>diagnosis</b> - Entered diagnosis value
 * <li><b>notes</b> - Entered notes value
 * </ul>
 * </p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public final class RecordBean extends BaseBean {
  // Instance Variables
  private String patientId = "";
  private String physicianName = "";
  private String date = "";
  private String symptoms = "";
  private String diagnosis = "";
  private String notes = "";
  private VitalSignsBean vitalSignsBean = new VitalSignsBean();
  private List prescriptionBeans = new ArrayList();

  // Constuctors
  public RecordBean() {  }

  public RecordBean(Record record) {
    if (record == null) return;
    super.setId(record.getId());
    this.patientId = toStr(record.getPatientId());
    this.physicianName = record.getPhysicianName();
    this.date = MedRecWebAppUtils.getDisplayDate(record.getRecordDate());
    this.symptoms = record.getSymptoms();
    this.diagnosis = record.getDiagnosis();
    this.notes = record.getNotes();
    if (record.getVitalSigns() != null)
      this.vitalSignsBean = new VitalSignsBean(record.getVitalSigns());
    this.prescriptionBeans =
        PrescriptionBean.toPrescriptionBeans(record.getPrescriptions());
  }

  public RecordBean(Integer id,
                    String patientId,
                    String physicianName,
                    String date,
                    String symptoms,
                    String diagnosis,
                    String notes,
                    VitalSignsBean vitalSignsBean,
                    PrescriptionBean[] prescriptionBeans) {
    super.setId(id);
    this.patientId = patientId;
    this.physicianName = physicianName;
    this.date = date;
    this.symptoms = symptoms;
    this.diagnosis = diagnosis;
    this.notes = notes;
    this.vitalSignsBean = vitalSignsBean;
    setPrescriptions(prescriptionBeans);
  }

  public RecordBean(Integer id,
                    Integer patientId,
                    String physicianName,
                    String date,
                    String symptoms,
                    String diagnosis,
                    String notes,
                    VitalSignsBean vitalSignsBean,
                    PrescriptionBean[] prescriptionBeans) {
    super.setId(id);
    this.patientId = toStr(patientId);
    this.physicianName = physicianName;
    this.date = date;
    this.symptoms = symptoms;
    this.diagnosis = diagnosis;
    this.notes = notes;
    this.vitalSignsBean = vitalSignsBean;
    setPrescriptions(prescriptionBeans);
  }

  public RecordBean(String id,
                    String physicianName,
                    String date,
                    String symptoms,
                    String diagnosis) {
    super.setId(id);
    this.physicianName = physicianName;
    this.date = date;
    this.symptoms = symptoms;
    this.diagnosis = diagnosis;
  }

  public RecordBean(Integer id,
                    String physicianName,
                    String date,
                    String symptoms,
                    String diagnosis) {
    super.setId(id);
    this.physicianName = physicianName;
    this.date = date;
    this.symptoms = symptoms;
    this.diagnosis = diagnosis;
  }

  // Getters
  public String getPatientId() {
    return this.patientId;
  }

  public String getPhysicianName() {
    return "Dr. "+this.physicianName;
  }

  public String getDate() {
    return this.date;
  }

  public String getSymptoms() {
    return this.symptoms;
  }

  public String getDiagnosis() {
    return this.diagnosis;
  }

  public String getNotes() {
    return this.notes;
  }

  public VitalSignsBean getVitalSignsBean() {
    if (vitalSignsBean == null) vitalSignsBean = new VitalSignsBean();
    return vitalSignsBean;
  }

  public List getPrescriptionBeans() {
    return this.prescriptionBeans;
  }

  // Setters
  public void setPatientId(String pPatientId) {
    this.patientId = pPatientId;
  }

  public void setPhysicianName(String pPhysicianName) {
    this.physicianName = pPhysicianName;
  }

  public void setDate(String pDate) {
    this.date = pDate;
  }

  public void setSymptoms(String pSymptoms) {
    this.symptoms = pSymptoms;
  }

  public void setDiagnosis(String pDiagnosis) {
    this.diagnosis = pDiagnosis;
  }

  public void setNotes(String pNotes) {
    this.notes = pNotes;
  }

  public void setVitalSignsBean(VitalSignsBean pVitalSignsBean) {
    this.vitalSignsBean = pVitalSignsBean;
  }

  public void setPrescriptions(PrescriptionBean[] pPrescriptionBeans) {
    this.prescriptionBeans = Arrays.asList(pPrescriptionBeans);
  }

  // Update method
  public void update(RecordBean recordBean) {
    this.symptoms = recordBean.getSymptoms();
    this.diagnosis = recordBean.getDiagnosis();
    this.notes = recordBean.getNotes();
    this.vitalSignsBean.update(recordBean.getVitalSignsBean());
  }

  // utility
  public int getNumOfPrescriptions() {
    return (this.prescriptionBeans == null ? 0 : this.prescriptionBeans.size());
  }

  public void addPrescription(PrescriptionBean pPrescriptionBean) {
    this.prescriptionBeans.add(pPrescriptionBean);
  }

  public void removePrescription(String pPrescriptionId) {
    if (getNumOfPrescriptions() > 1)
      this.prescriptionBeans.remove(Integer.parseInt(pPrescriptionId));
    else
      this.prescriptionBeans.clear();
  }

  /**
   * <p>Validate record.</p>
   *
   * @param mapping
   * @param request
   *
   * @return ActionErrors
   */
  public ActionErrors validate(ActionMapping mapping,
                               HttpServletRequest request) {
    ActionErrors errors = new ActionErrors();
    // only validate if the user has clicked "Login"
    String loginSubmit = Resources.getMessage(request, "button.Save");
    if (loginSubmit.equals(request.getParameter("action"))) {
      errors = super.validate(mapping, request);
    }
    return errors;
  }

  /**
   * <p>Converts record presentation bean to record value object.</p>
   *
   * @return Record
   */
  public Record toRecord() {
    Record record = new Record();
    record.setPatientId(getPatientId());
    record.setRecordDate(str2Date(getDate()));
    record.setSymptoms(getSymptoms());
    record.setDiagnosis(getDiagnosis());
    record.setNotes(getNotes());
    record.setVitalSigns(getVitalSignsBean().toVitalSigns());
    record.setPrescriptions((Prescription[])PrescriptionBean.toPrescriptions(prescriptionBeans).toArray());
    // record.setPhysician(); FIXME
    return record;
  }

  public static List toRecordBeans(Record[] records) {
    if (records != null && records.length > 0) {
      List recordBeans = new ArrayList(records.length);
      for (Record record : records) {
        recordBeans.add(new RecordBean(record));
      }
      return recordBeans;
    } else {
      return new ArrayList();
    }
  }

  // Utility methods
  public String toString() {
    StringBuffer str = new StringBuffer();
    str.append("Record [");
    str.append("PatId: ").append(patientId);
    str.append(" | PhysName: ").append(physicianName);
    str.append(" | DOB: ").append(date);
    str.append(" | Syms: ").append(symptoms);
    str.append(" | Diag: ").append(diagnosis);
    str.append(" | Notes: ").append(notes);
    str.append(" | Vitals: ");
    str.append((vitalSignsBean == null ? "null" : vitalSignsBean.toString()));
    str.append(" | ").append(MedRecWebAppUtils.col2Str(prescriptionBeans));
    str.append("]");
    return str.toString();
  }

}
