package com.bea.medrec.web.patient.actions;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.bea.medrec.domain.Patient;
import com.bea.medrec.exceptions.MedRecException;
import com.bea.medrec.utils.MedRecLog4jFactory;
import com.bea.medrec.web.beans.PatientBean;
import com.bea.medrec.web.exceptions.ClientException;

/**
 * <p>Controller to update user profile requests.</p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public class EditProfileAction extends PatientBaseLookupDispatchAction {
  private static Logger logger =
      MedRecLog4jFactory.getLogger(EditProfileAction.class.getName());

  /**
   * <p>Mapping of action to method.</p>
   *
   * @return Map
   */
  protected Map getKeyMethodMap() {
    Map<String,String> map = new HashMap<String,String>();
    map.put("button.Save", "save");
    map.put("button.Cancel", "cancel");
    return map;
  }

  /**
   * <p>Default behavior.</p>
   *
   * @return ActionForward
   */
  public ActionForward defaultMethod(ActionMapping mapping,
                                     ActionForm form,
                                     HttpServletRequest request,
                                     HttpServletResponse response)
      throws Exception {
    logger.debug("Default method execution.");
    
    Patient patient = (Patient)getSessionAttribute(request,
        PATIENT);    
    request.setAttribute (PATIENT_BEAN, new PatientBean (patient));
    
    // First time thru.
    return mapping.findForward("edit.profile");
  }

  /**
   * <p>Cancel edit patient profile.</p>
   *
   * @return ActionForward
   */
  public ActionForward cancel(ActionMapping mapping,
                              ActionForm form,
                              HttpServletRequest request,
                              HttpServletResponse response)
      throws Exception {
    logger.info("Cancel edit profile.");
    
    Patient patient = (Patient)getSessionAttribute(request,
        PATIENT);    
    request.setAttribute (PATIENT_BEAN, new PatientBean (patient));
    
    return mapping.findForward("view.profile");
  }

  /**
   * <p>Save updated patient profile.</p>
   *
   * @return ActionForward
   */
  public ActionForward save(ActionMapping mapping,
                            ActionForm form,
                            HttpServletRequest request,
                            HttpServletResponse response)
      throws ClientException, Exception {
    
    logger.debug("Save updated profile.");
    Patient patient = null;
    PatientBean updatedPatient = null;

    // Get original patient from session.
    patient = (Patient)getSessionAttribute(request, PATIENT);
    
    // Populate new patient from form, set original id values.
    updatedPatient = (PatientBean) form;
    updatedPatient.exportChanges (patient);
    
    // Set new patient on session.  View presentation comes from session.
    request.setAttribute (PATIENT_BEAN, updatedPatient);
    
    try {
      // Update persistent patient information with new data.
      patient = medRecClientServiceFacade.updatePatient(patient);     
    } 
    catch (MedRecException e) {
      throwClientException(e, mapping, "view.profile");
    }
    finally {
      setSessionAttribute(request, PATIENT, patient);
    }
    
    return mapping.findForward("view.profile");
  }
}
