package com.bea.medrec.web.patient.actions;

import com.bea.medrec.exceptions.MedRecException;
import com.bea.medrec.utils.MedRecLog4jFactory;
import com.bea.medrec.web.beans.PatientBean;
import com.bea.medrec.web.exceptions.ClientException;
import com.bea.medrec.web.patient.beans.RegistrationBean;
import java.util.HashMap;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

/**
 * <p>Handles all request during the registration process.</p<
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public class RegisterAction extends PatientBaseLookupDispatchAction {

  private static Logger logger =
      MedRecLog4jFactory.getLogger(RegisterAction.class.getName());

  /**
   * <p>Mapping of action to method.</p>
   *
   * @return Map
   */
  protected Map getKeyMethodMap() {
    Map<String,String> map = new HashMap<String,String>();
    map.put("button.Cancel", "cancel");
    map.put("button.Register", "register");
    return map;
  }

  /**
   * <p>Default behavior.</p>
   *
   * @return ActionForward
   */
  public ActionForward defaultMethod(ActionMapping mapping,
                                     ActionForm form,
                                     HttpServletRequest request,
                                     HttpServletResponse response)
      throws Exception {
    // First time thru.
    logger.debug("Default method executions.");
    setupLocale(request);
    return mapping.findForward("register.home");
  }

  /**
   * <p>Cancel edit patient profile.</p>
   *
   * @return ActionForward
   */
  public ActionForward cancel(ActionMapping mapping,
                              ActionForm form,
                              HttpServletRequest request,
                              HttpServletResponse response)
      throws Exception {
    logger.info("Cancel registration.");
    return new ActionForward("medrec.startpage", true);
  }

  /**
   * <p>Register new patient user.</p>
   *
   * @return ActionForward
   */
  public ActionForward register(ActionMapping mapping,
                                ActionForm form,
                                HttpServletRequest request,
                                HttpServletResponse response)
      throws ClientException, Exception {
    logger.info("New user registration.");
    RegistrationBean registrationBean = (RegistrationBean) form;
    PatientBean patientBean = registrationBean.getPatientBean();

    // The email address is the username.
    patientBean.setEmail(registrationBean.getUserBean().getUsername());


    try {
      // Send registration to be processed.
      medRecClientServiceFacade.saveRegistration(registrationBean.toRegistration());
    } catch (MedRecException e) {
      throwClientException(e, mapping, "validate.registration.failure");
    }
    return mapping.findForward("register.success");
  }
}
