package com.bea.medrec.web.patient.actions;

import com.bea.medrec.domain.Patient;
import com.bea.medrec.domain.Record;
import com.bea.medrec.exceptions.MedRecException;
import com.bea.medrec.utils.MedRecLog4jFactory;
import com.bea.medrec.web.beans.PatientBean;
import com.bea.medrec.web.beans.RecordBean;
import com.bea.medrec.web.exceptions.ClientException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

/**
 * <p>Controller to retrieve a particular medical record.</p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public class ViewRecordAction extends PatientBaseAction {

  private static Logger logger =
      MedRecLog4jFactory.getLogger(ViewRecordAction.class.getName());

  /**
   * <p>Process the specified HTTP request, and create the corresponding HTTP
   * response (or forward to another web component that will create it).
   * Return an <code>ActionForward</code> instance describing where and how
   * control should be forwarded.
   * <br>
   * Retrieves a particular record.
   * </p>
   *
   * @param mapping  The ActionMapping used to select this instance
   * @param form  The optional ActionForm bean for this request (if any)
   * @param request  The HTTP request we are processing
   * @param response  The HTTP response we are creating
   */
  public ActionForward executeAction(ActionMapping mapping,
                                     ActionForm form,
                                     HttpServletRequest request,
                                     HttpServletResponse response)
      throws ClientException, Exception {
    Record record = null;
    RecordBean recordBean = null;
    Patient patient=null;
    PatientBean patientBean=null;
    
    String recordId = request.getParameter("id");
    logger.debug("RecId: " + recordId);

      if (isEmpty(recordId)) {
        throw new ClientException("Record not specified.");
      }

    try {
      // Pass record id to be retrieved.
      record = medRecClientServiceFacade.getRecord(Integer.valueOf(recordId));
      if (record == null) throw new ClientException("Record not found.");
      
      patient=new Patient ();
      patient.setId(record.getPatientId());
      patient = medRecClientServiceFacade.getPatient(patient);
    } catch (MedRecException e) {
      throwClientException(e, mapping, "view.records.summary");
    }

    // Convert record value object to presentation object.
    recordBean = new RecordBean(record);
    patientBean=new PatientBean (patient);

    // Let's see the record.
    logger.debug(recordBean.toString());

    // Set on request to be display by view.
    request.setAttribute(RECORD_BEAN, recordBean);
    request.setAttribute(PATIENT_BEAN, patientBean);

    return mapping.findForward("view.record");
  }
}
