package com.bea.medrec.web.patient.actions;

import com.bea.medrec.domain.Patient;
import com.bea.medrec.domain.RecordsSummary;
import com.bea.medrec.exceptions.MedRecException;
import com.bea.medrec.utils.MedRecLog4jFactory;
import com.bea.medrec.web.beans.PatientBean;
import com.bea.medrec.web.beans.PrescriptionBean;
import com.bea.medrec.web.beans.RecordBean;
import com.bea.medrec.web.exceptions.ClientException;
import com.bea.medrec.web.utils.MedRecWebAppUtils;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

/**
 * <p>Retrieves all records for a patient.  Records are returned
 * in abbreviated form in order to display a summary of
 * each record.</p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public class ViewRecordsSummaryAction extends PatientBaseAction {

  private static Logger logger =
      MedRecLog4jFactory.getLogger(ViewRecordsSummaryAction.class.getName());

 /**
  * <p>Process the specified HTTP request, and create the corresponding HTTP
  * response (or forward to another web component that will create it).
  * Return an <code>ActionForward</code> instance describing where and how
  * control should be forwarded.
  * <br>
  * Retrieves a patients entire medical record history.
  * Information includes summarized views of records and prescriptions.
  * </p>
  *
  * @param mapping  The ActionMapping used to select this instance
  * @param form  The optional ActionForm bean for this request (if any)
  * @param request  The HTTP request we are processing
  * @param response  The HTTP response we are creating
  */
  public ActionForward executeAction(ActionMapping mapping,
                                     ActionForm form,
                                     HttpServletRequest request,
                                     HttpServletResponse response)
    throws ClientException, Exception
  {
    logger.debug("Getting patients record summary.");
    Patient patient = (Patient)getSessionAttribute(request,
      PATIENT);
    RecordsSummary recordsSummary = null;
    
    if (patient!=null&&!MedRecWebAppUtils.isTemporaryId(patient.getId())) {
      logger.debug("Patient Id: "+patient.getId());

      try {        
        recordsSummary = medRecClientServiceFacade.getRecordsSummary(
          patient);
      }
      catch (MedRecException e) {
        throwClientException(e, mapping, "search.results");
      }
      
      logger.debug("Found records: "+recordsSummary.toString());
      logger.debug("Setting recordBeans on request");
      request.setAttribute(RECORD_BEANS,
          RecordBean.toRecordBeans(recordsSummary.getRecords()));
      logger.debug("Setting prescriptionBeans on request");
      request.setAttribute(PRESCRIPTION_BEANS,
          PrescriptionBean.toPrescriptionBeans(
              recordsSummary.getPrescriptions()));
      request.setAttribute (PATIENT_BEAN, new PatientBean (patient));
    }

    return mapping.findForward("view.records.summary");
  }
}