package com.bea.medrec.webservice;

import com.bea.medrec.domain.Record;
import com.bea.medrec.utils.MedRecLog4jFactory;
import javax.jws.WebMethod;
import javax.jws.WebService;
import javax.jws.WebResult;
import javax.jws.soap.SOAPBinding;
import org.apache.log4j.Logger;
import weblogic.jws.AsyncResponseBean;
import weblogic.jws.Policy;
import weblogic.jws.WLHttpTransport;

// Standard JWS annotation that specifies that the name of the Web Service is
// "MedRecRMWebServices", its public service name is "MedRecRMWebServices", and the
// targetNamespace used in the generated WSDL is "http://www.bea.com/medrec"
@WebService(name = "MedRecRMWebServicesPortType",
    serviceName = "MedRecRMWebServices",
    targetNamespace = "http://www.bea.com/medrec")

// Standard JWS annotation that specifies this is a document-literal-wrapped
// Web Service
@SOAPBinding(style=SOAPBinding.Style.DOCUMENT,
             use=SOAPBinding.Use.LITERAL,
             parameterStyle=SOAPBinding.ParameterStyle.WRAPPED)

// WebLogic Web Services use WS-Policy files to enable a destination endpoint
// to describe and advertise its reliable messaging capabilities and requirements.
// The WS-Policy specification provides a general purpose model and syntax to
// describe and communicate the policies of a Web service.
// These WS-Policy files are XML files that describe features such as the
// version of the WS-ReliableMessaging specification that is supported, the
// source endpoint's retransmission interval, the destination endpoint's
// acknowledgment interval, and so on
@Policy(uri="MedRecRMServicePolicy.xml", attachToWsdl=true)

@AsyncResponseBean()

// WebLogic-specific JWS annotation that specifies the port name is
// "MedRecRMWebServices", and the context path and service URI used to build
// the URI of the Web Service is "ws_rm_medrec/MedRecWebServices"
@WLHttpTransport(portName = "MedRecRMWebServicesPort",
    contextPath = "ws_rm_medrec",
    serviceUri = "MedRecRMWebServices")

/**
 * <p>MedRecWebServices provides an interface for all MedRec Web services.</p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public class MedRecRMWebServices extends MedRecBaseWebServices {
  private static Logger logger =
      MedRecLog4jFactory.getLogger(MedRecRMWebServices.class.getName());

  //  A D D   R E C O R D
  /**
   * <p>Accesses MedRec Web service adding a record, including
   * vital signs and prescriptions.</p>
   *
   * @param pRecord
   */
  @WebMethod()
  public Record addRecord(Record pRecord) throws Exception {
    logger.info("Adding record.");
    logger.debug(pRecord.toString());

    try {
      getMedRecServiceFacade().saveRecord(pRecord);
    } catch (Exception e) {
      logger.error("Exception occurred: "+e.getMessage(), e);
      throw e;
    }
    return pRecord;
  }
}
