package com.bea.physician.web.beans;

import com.bea.physician.domain.Address;
import com.bea.physician.web.utils.PhysicianWebAppUtils;

/**
 * <p>Form bean for addresses.
 * This form has the following fields,
 * with default values in square brackets:
 * <ul>
 * <li><b>street1</b> - Entered street name 1 value
 * <li><b>street2</b> - Entered street name 2 value
 * <li><b>city</b> - Entered city value
 * <li><b>state</b> - Entered state value
 * <li><b>zipCode</b> - Entered zip code value
 * <li><b>country</b> - Entered country value
 * </ul>
 * </p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public final class AddressBean extends BaseBean {

  // Instance Variables
  private String street1 = null;
  private String street2 = null;
  private String city = null;
  private String state = null;
  private String zipCode = null;
  private String country = null;

  // Constructors
  public AddressBean() {
  }

  public AddressBean(Address address) {
    if (address == null) return;
    super.setId(address.getId());
    this.street1 = address.getStreetName1();
    this.street2 = address.getStreetName2();
    this.city = address.getCity();
    this.state = address.getState();
    this.zipCode = address.getZipCode();
    this.country = address.getCountry();
  }

  public AddressBean(String id,
                     String street1,
                     String street2,
                     String city,
                     String state,
                     String zipCode,
                     String country) {
    super.setId(id);
    this.street1 = street1;
    this.street2 = street2;
    this.city = city;
    this.state = state;
    this.zipCode = zipCode;
    this.country = country;
  }

  public AddressBean(Integer id,
                     String street1,
                     String street2,
                     String city,
                     String state,
                     String zipCode,
                     String country) {
    super.setId(id);
    this.street1 = street1;
    this.street2 = street2;
    this.city = city;
    this.state = state;
    this.zipCode = zipCode;
    this.country = country;
  }

  public String getStreetName1() {
    return this.street1;
  }

  public String getStreetName2() {
    return this.street2;
  }

  public String getCity() {
    return this.city;
  }

  public String getState() {
    return this.state;
  }

  public String getZipCode() {
    return this.zipCode;
  }

  public String getCountry() {
    return this.country;
  }

  public void setStreetName1(String street1) {
    this.street1 = PhysicianWebAppUtils.cleanParam(street1);
  }

  public void setStreetName2(String street2) {
    this.street2 = PhysicianWebAppUtils.cleanParam(street2);
  }

  public void setCity(String city) {
    this.city = PhysicianWebAppUtils.cleanParam(city);
  }

  public void setState(String state) {
    this.state = PhysicianWebAppUtils.cleanParam(state);
  }

  public void setZipCode(String zipCode) {
    this.zipCode = PhysicianWebAppUtils.cleanParam(zipCode);
  }

  public void setCountry(String country) {
    this.country = PhysicianWebAppUtils.cleanParam(country);
  }

  // Public Methods
  public void reset() {
    this.street1 = "";
    this.street2 = "";
    this.city = "";
    this.state = "";
    this.zipCode = "";
    this.country = "";
  }

  /**
   * <p>Converts address presentation bean to address value object.</p>
   *
   * @return Address
   */
  public Address toAddress() {
    return new Address(this.getId(),
        this.getStreetName1(),
        this.getStreetName2(),
        this.getCity(),
        this.getState(),
        this.getZipCode(),
        this.getCountry());
  }


  public String toString() {
    StringBuffer str = new StringBuffer();
    str.append("Address[Id: " + super.getId());
    str.append(" | StreetName1: " + street1);
    str.append(" | StreetName2: " + street2);
    str.append(" | City: " + city);
    str.append(" | State: " + state);
    str.append(" | ZipCode: " + zipCode);
    str.append(" | Country: " + country);
    str.append("]");

    return str.toString();
  }
}
