package com.bea.physician.web.physician.actions;

import com.bea.medrec.domain.Patient;
import com.bea.physician.domain.Prescription;
import com.bea.physician.utils.PhysicianLog4jFactory;
import com.bea.physician.web.beans.PatientBean;
import com.bea.physician.web.beans.PrescriptionBean;
import com.bea.physician.web.beans.RecordBean;
import com.bea.physician.web.utils.PhysicianWebAppUtils;
import java.util.HashMap;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

/**
 * <p>Controller to handle the creation of a prescriptions.</p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public class CreatePrescriptionAction
    extends PhysBaseLookupDispatchAction {

  private static Logger logger =
      PhysicianLog4jFactory.getLogger(CreatePrescriptionAction.class.getName());

 /**
  * <p>Mapping of action to method.</p>
  *
  * @return Map
  */
  protected Map getKeyMethodMap() {
    Map<String,String> map = new HashMap<String,String>();
    map.put("button.Save", "save");
    map.put("button.Cancel", "cancel");
    return map;
  }

 /**
  * <p>Default behavior.</p>
  *
  * @return ActionForward
  */
  public ActionForward defaultMethod(ActionMapping mapping,
                                     ActionForm form,
                                     HttpServletRequest request,
                                     HttpServletResponse response)
  {
    // First timers
    // Set new token for dup form submission check.
    logger.info("Default action method.");
    logger.debug("setting token.");
    saveToken(request);
    return mapping.findForward("create.prescription");
  }


 /**
  * <p>Cancel prescribe medication.</p>
  *
  * @return ActionForward
  */
  public ActionForward cancel(ActionMapping mapping,
                              ActionForm form,
                              HttpServletRequest request,
                              HttpServletResponse response)
  {
    logger.info("Cancel create prescription.");
    return mapping.findForward("cancel.prescription");
  }

 /**
  * <p>Save prescription to be recorded.</p>
  *
  * @return ActionForward
  */
  public ActionForward save(ActionMapping mapping,
                            ActionForm form,
                            HttpServletRequest request,
                            HttpServletResponse response)
  {
    logger.info("Save prescription.");
    PrescriptionBean prescriptionBean = (PrescriptionBean)form;
    RecordBean recordBean = null;

    // Set patient and physician ids and current date.
    setPrescriptionValues(request, prescriptionBean);

    // Every's okay.  Get record from session,
    // add prescription, then reattach to session.
    recordBean = (RecordBean)getSessionAttribute(request, RECORD_BEAN);

    // Add new prescription to record.
    logger.debug("Adding : "+prescriptionBean.toString());
    recordBean.addPrescription(prescriptionBean);
    logger.debug("Num of prescriptions: "+recordBean.getNumOfPrescriptions());

    // Set record to session.
    setSessionAttribute(request, RECORD_BEAN, recordBean);
    return mapping.findForward("save.prescription.success");
  }

 /**
  * Sets known values from the session.
  */
  private void setPrescriptionValues(HttpServletRequest request,
                                     PrescriptionBean prescriptionBean) {
    logger.info("Setting patient and physician ids from session.");

    PatientBean patient =
      (PatientBean)getSessionAttribute(request, PATIENT_BEAN);

    prescriptionBean.setPatientId(patient.getId().toString ());
    prescriptionBean.setDatePrescribed(PhysicianWebAppUtils.getCurrentDate());
  }
}
