package com.bea.physician.web.physician.actions;

import com.bea.physician.domain.RecordsSummary;
import com.bea.physician.utils.PhysicianLog4jFactory;
import com.bea.physician.web.beans.PatientBean;
import com.bea.physician.web.beans.PrescriptionBean;
import com.bea.physician.web.beans.RecordBean;
import com.bea.physician.web.exceptions.ClientException;
import com.bea.physician.exceptions.PhysicianException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import java.util.List;

/**
 * <p>Retrieves all records for a patient.  Records are returned
 * in abbreviated form in order to display a summary of
 * each record.</p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public class PhysViewRecordsSummaryAction
    extends PhysBaseAction {

  private static Logger logger =
      PhysicianLog4jFactory.getLogger(PhysViewRecordsSummaryAction.class.getName());

  /**
   * <p>Process the specified HTTP request, and create the corresponding HTTP
   * response (or forward to another web component that will create it).
   * Return an <code>ActionForward</code> instance describing where and how
   * control should be forwarded.
   * <br>
   * Retrieves a patients entire medical record history.
   * Information includes summarized views of records and prescriptions.
   * </p>
   *
   * @param mapping  The ActionMapping used to select this instance
   * @param form  The optional ActionForm bean for this request (if any)
   * @param request  The HTTP request we are processing
   * @param response  The HTTP response we are creating
   */
  public ActionForward executeAction(ActionMapping mapping,
                                     ActionForm form,
                                     HttpServletRequest request,
                                     HttpServletResponse response)
      throws ClientException, Exception {
    String nextPage = "view.records.summary";
    String requestPatId = (String) request.getParameter("id");
    PatientBean sessionPatient = (PatientBean) getSessionAttribute(request,
        PATIENT_BEAN);
    // Check for existing patient on session.
    if (sessionPatient != null) {
      // Check to see if request patient is the same as existing patient.
      if (requestPatId != null && !sessionPatient.getId().equals(requestPatId)) {
        // New patient selected from results page.
        nextPage = "search.results";
      } else {
        logger.debug("Selected patient: "+sessionPatient.toString());
        try {
          // Get records summary for existing patient.
          getMedicalRecords(request, sessionPatient.getId());
        } catch (PhysicianException e) {
          throwClientException(e, mapping, "search.results");
        }
      }
    } else if (requestPatId != null) {
      // First time thru with selected patient from search results.
      List patientBeans = (List) getSessionAttribute(
          request, PATIENT_BEANS);
      if (patientBeans == null) {
        logger.info("Recreating results from previous search.");
        nextPage = "search.results";
      } else {
        logger.info("Setting selected patient on session.");
        PatientBean patient = findPatientInList(requestPatId, patientBeans);
        super.setSessionAttribute(request, PATIENT_BEAN, patient);
        // This removed all search results from
        // session after a resultant has been choosen.
        super.removeSessionAttribute(request, PATIENT_BEANS);
        getMedicalRecords(request, requestPatId);
      }
    }

    logger.debug("Redirecting to "+nextPage);
    return mapping.findForward(nextPage);
  }

  /**
   * Retrieves medical record summary fro a given patient id.
   */
  private void getMedicalRecords(HttpServletRequest request, String patId)
      throws Exception {
    logger.info("Getting patient's medical record summary.");
    logger.debug("Patient id = "+patId);
    RecordsSummary recordsSummary =
        physicianService.getRecordsSummary(Integer.valueOf(patId));
    logger.debug("Found records: "+recordsSummary.toString());
    logger.debug("Setting recordBeans on request");
    request.setAttribute(RECORD_BEANS,
        RecordBean.toRecordBeans(recordsSummary.getRecords()));
    logger.debug("Setting prescriptionBeans on request");
    request.setAttribute(PRESCRIPTION_BEANS,
        PrescriptionBean.toPrescriptionBeans(recordsSummary.getPrescriptions()));
  }

  /**
   * User selects a patient from the search results collection.  This
   * method retrieves that patient from the collection.
   */
  private PatientBean findPatientInList(String pPatientId,
                                         List pPatientBeans) {
    logger.info("Finding patient in session patient collection.");
    logger.debug("PatId to find: "+pPatientId);
    // declare local variables
    PatientBean patientBean = null;
    for (int i = 0; i < pPatientBeans.size(); i++) {
      patientBean =  (PatientBean)pPatientBeans.get(i);
      logger.debug("Found PatId: "+patientBean.getId());
      if (patientBean.getId().equals(pPatientId))
        break;
    }
    return patientBean;
  }

}
