package com.bea.physician.web.physician.actions;

import com.bea.physician.domain.Patient;
import com.bea.physician.utils.PhysicianLog4jFactory;
import com.bea.physician.web.beans.PatientBean;
import com.bea.physician.web.exceptions.ClientException;
import com.bea.physician.web.physician.beans.SearchBean;
import com.bea.physician.service.PhysicianService;
import com.bea.physician.exceptions.PhysicianException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessages;

/**
 * <p>Search service.  Handles all search requests.</p>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public class SearchResultsAction extends PhysBaseLookupDispatchAction {

  private static Logger logger =
      PhysicianLog4jFactory.getLogger(SearchResultsAction.class.getName());

  /**
   * <p>Mapping of action to method.</p>
   *
   * @return Map
   */
  protected Map getKeyMethodMap() {
    Map<String,String> map = new HashMap<String,String>();
    map.put("button.Search", "search");
    return map;
  }

  /**
   * <p>Default behavior.</p>
   *
   * @return ActionForward
   */
  public ActionForward defaultMethod(ActionMapping mapping,
                                     ActionForm form,
                                     HttpServletRequest request,
                                     HttpServletResponse response)
      throws Exception {
    logger.info("Default action method.");
    SearchBean search = (SearchBean) getSessionAttribute(request,
        PREVIOUS_SEARCH);

    // If search null, then new search.
    if (search == null) return mapping.findForward("search.home");

    // Process search.
    try {
      processSearch(request, search);
    } catch (PhysicianException e) {
      throwClientException(e, mapping, "search.home");
    }
    return mapping.findForward("search.results");
  }

  /**
   * <p>Searches based on user's criteria.</p>
   *
   * @return ActionForward
   */
  public ActionForward search(ActionMapping mapping,
                              ActionForm form,
                              HttpServletRequest request,
                              HttpServletResponse response)
      throws ClientException, Exception {
    logger.info("New search.");
    SearchBean search = (SearchBean) form;

    // Validate search.
    // Report any errors we have discovered back to the original form.
    ActionMessages errorMsgs = search.validate();
    if (!errorMsgs.isEmpty()) {
      saveErrors(request, errorMsgs);
      return mapping.findForward("search.invalid");
    }

    // Process search.
    try {
      processSearch(request, search);
    } catch (PhysicianException e) {
      throwClientException(e, mapping, "search.home");
    }
    return mapping.findForward("search.results");
  }

  /**
   * <p>Search for patients.  Once retrieved, store the results to the
   * session.  Also save search criteria to handle when user returns to
   * search results page.</p>
   */
  private void processSearch(HttpServletRequest request, SearchBean search)
      throws PhysicianException {
    logger.info("Process search.");

   // pass transformed search value object.
   List patients = physicianService.searchPatients(search.toSearch());

    logger.debug("Removing old patient.");
    removeSessionAttribute(request, PATIENT_BEAN);

    logger.debug("Setting patient result collection.");
    setSessionAttribute(request, PATIENT_BEANS,
        PatientBean.toPatientBeans(patients));

    logger.debug("Setting search criteria.");
    setSessionAttribute(request, PREVIOUS_SEARCH, search);

  }
}
