package com.bea.physician.web.physician.beans;

import com.bea.physician.domain.Search;
import com.bea.physician.utils.PhysicianLog4jFactory;
import com.bea.physician.web.beans.BaseBean;
import org.apache.log4j.Logger;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

/**
 * Form bean for the patient search page.
 * This form has the following fields:
 * <ul>
 * <li><b>last name</b> - Last name search option
 * <li><b>ssn</b> - Social security number search option
 * </ul>
 *
 * @author Copyright (c) @COPYRIGHT_CURRENTYEAR by BEA Systems. All Rights Reserved.
 */
public final class SearchBean extends BaseBean {
  private static Logger logger = PhysicianLog4jFactory.getLogger(SearchBean.class.getName());

  // Instance Variables
  private String lastName = "";
  private String ssn = "";

  // Constuctors
  public SearchBean() {
  }

  public SearchBean(String lastName, String ssn) {
    this.lastName = lastName;
    this.ssn = ssn;
  }

  // Getters
  public String getLastName() {
    return this.lastName;
  }

  public String getSsn() {
    return this.ssn;
  }

  // Setters
  public void setLastName(String lastName) {
    this.lastName = lastName;
  }

  public void setSsn(String ssn) {
    this.ssn = ssn;
  }

  /**
   * <p>Validate search.  Due to the complexity of the input fields, this
   * bean requires manual validation verus Struts' validation.</p>
   *
   * @return ActionErrors
   */
  public ActionMessages validate() {
    logger.debug("Validating search bean.");
    logger.debug(toString());

    ActionMessages errorMsgs = new ActionMessages();

    if ((isEmpty(lastName) && isEmpty(ssn))
        || (isNotEmpty(lastName) && isNotEmpty(ssn))) {
      logger.warn("Entires emtpy or all populated.");
      errorMsgs.add("multipleEntries", new ActionError("enter.one.option.only"));
    } else {
      if (isEmpty(lastName) && !isValidSsn(ssn)) {
        errorMsgs.add("ssn", new ActionMessage("invalid.ssn"));
      }
    }

    if (!errorMsgs.isEmpty()) {
      logger.warn("SearchBean invalid. " + errorMsgs.size() + " errors found.");
    }

    return errorMsgs;
  }

  /**
   * <p>Converts search presentation bean to search value object.</p>
   *
   * @return RecordWS
   */
  public Search toSearch() {
    return new Search(getLastName(), getSsn());
  }

  public String toString() {
    StringBuffer str = new StringBuffer();
    str.append("Search [");
    str.append("LastName: " + lastName);
    str.append(" | SSN: " + ssn);
    str.append("]");

    return str.toString();
  }

}