package com.bea.physician.web.utils;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import javax.servlet.http.HttpServlet;
import org.apache.log4j.Appender;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;
import org.apache.log4j.xml.DOMConfigurator;
import weblogic.logging.log4j.Log4jLoggingHelper;


/**
 * <p>Controls Log4j logging level.  Implemented as a servlet so
 * that logging levels can be adjusted by redeploying the webapp.
 * Log file is determined by "log4j.config" set as a system
 * property in the server startup file.</p>
 *
 * @author Copyright (c) 2004 by BEA Systems. All Rights Reserved.
 */
public class LoggingInit extends HttpServlet {

  public void init() {
    logMsg("Notice", "Initializing MedRec logger - appending to WLS Server "+
        "logger");
    Logger tmpLogger;
    try {
     tmpLogger = Log4jLoggingHelper.getLog4jServerLogger();
     Appender app = Logger.getRootLogger().getAppender(
         "MedRecLog4jRollingFileAppender");
     if (app != null) {
       tmpLogger.addAppender(app);
     } else {
       throw new Exception("MedRecLog4jRollingFileAppender is null");
     }
   } catch(Exception ex) {
     logMsg("Warning", "Unable to get a reference to the log4j Logger. Will "+
         "use non-server logger: "+ex.getMessage());
     String logFile = System.getProperty("log4j.configuration");
     if (logFile == null) {
       logMsg("Notice", "Log file not found, calling BasicConfigurator");
       BasicConfigurator.configure();
     } else {
       logFile = logFile.substring(logFile.indexOf(':')+1);
       logMsg("Notice", "Calling DOMConfigurator on: "+logFile);
       DOMConfigurator.configure(logFile);
     }
    }
  }

  private void logMsg(String type, String message) {
    System.out.println("<"+getDisplayDate()+"> <"+type+"> <MedRec Logging>  "+
        message);
  }

  private String getDisplayDate() {
    SimpleDateFormat format = new SimpleDateFormat("MMM dd, yyyy hh:mm:ss a z");
    return format.format(Calendar.getInstance().getTime());
  }
}
